@@ -27,6 +27,7 @@
 #include "Routing.h"
 #include "rwlock.h"
 #include "gk.h"
+#include "h323util.h"
 #include "GkStatus.h"
 
 void ReloadHandler(); // avoid to include...
@@ -37,7 +38,7 @@ static const char *filteringsec="GkStatus::Filtering";
 // a very lightweight implementation of telnet socket
 class TelnetSocket : public ServerSocket {
 #ifndef LARGE_FDSET
-	PCLASSINFO(TelnetSocket, TCPSocket)
+	PCLASSINFO(TelnetSocket, ServerSocket)
 #endif
 public:
 	typedef PTelnetSocket::Options Options;
@@ -49,7 +50,7 @@ public:
 #ifdef LARGE_FDSET
 	virtual bool Accept(YaTCPSocket &);
 #else
-	virtual BOOL Accept(PSocket &);
+	virtual PBoolean Accept(PSocket &);
 #endif
 
 	virtual int ReadChar();
@@ -221,6 +222,10 @@ private:
 		PString cmd
 		);
 
+	/** Print error message to status port and trace
+	*/
+	void CommandError(const PString & msg);
+
     // Adds regular expression filter
     void AddFilter(
 	// filter vector
@@ -236,7 +241,7 @@ private:
 	// filter vector
 	std::vector<PString>& regexFilters,
 	// Index of filter to be removed
-	const PINDEX index
+	unsigned int index
 	);
 
     // Checks whether the given string is to be exclude
@@ -298,7 +303,7 @@ TelnetSocket::TelnetSocket() : m_needEcho(false), m_state(StateNormal)
 #ifdef LARGE_FDSET
 bool TelnetSocket::Accept(YaTCPSocket & socket)
 #else
-BOOL TelnetSocket::Accept(PSocket & socket)
+PBoolean TelnetSocket::Accept(PSocket & socket)
 #endif
 {
 	if (!TCPSocket::Accept(socket))
@@ -474,9 +479,7 @@ namespace {
 PString PrintGkVersion()
 {
 	return PString("Version:\r\n") + Toolkit::GKVersion() +
-		"GkStatus: Version(2.0) Ext()\r\n"
-		"Toolkit: Version(1.0) Ext(" + Toolkit::Instance()->GetName() + ")\r\n" 
-		+ SoftPBX::Uptime() + "\r\n;\r\n";
+		SoftPBX::Uptime() + "\r\n;\r\n";
 }
 
 }
@@ -498,7 +501,7 @@ void GkStatus::AuthenticateClient(
 {
 	if (newClient->Authenticate()) {
 		newClient->SetTraceLevel(GkConfig()->GetInteger("StatusTraceLevel", MAX_STATUS_TRACE_LEVEL));
-		PTRACE(1, "STATUS\tNew client authenticated succesfully: " << newClient->WhoAmI()
+		PTRACE(1, "STATUS\tNew client authenticated successfully: " << newClient->WhoAmI()
 			<< ", login: " << newClient->GetUser()
 			);
 		// the welcome messages
@@ -512,7 +515,6 @@ void GkStatus::AuthenticateClient(
 		newClient->WriteString("\r\nAccess forbidden!\r\n");
 		newClient->Flush();
 		delete newClient;
-		newClient = NULL;
 	}
 }
 
@@ -728,6 +730,10 @@ void GkStatus::OnStart()
 	m_commands["filter"] = e_Filter;
 	m_commands["printexcludefilters"] = e_PrintExcludeFilters;
 	m_commands["printincludefilters"] = e_PrintIncludeFilters;
+	m_commands["printprefixcapacities"] = e_PrintPrefixCapacities;
+	m_commands["printpc"] = e_PrintPrefixCapacities;
+	m_commands["printcc"] = e_PrintCapacityControlRules;
+	m_commands["sendproceeding"] = e_SendProceeding;
 }
 
 void GkStatus::ReadSocket(
@@ -746,15 +752,14 @@ void GkStatus::CleanUp()
 		PWaitAndSignal lock(m_rmutex);
 		iterator iter = m_removed.begin();
 		while (iter != m_removed.end()) {
-			iterator i = iter++;
-			StatusClient *client = static_cast<StatusClient *>(*i);
+			StatusClient *client = static_cast<StatusClient *>(*iter);
 			if (!client->IsBusy()) {
-				m_removed.erase(i);
+				iter = m_removed.erase(iter);
 				--m_rmsize;
 				delete client;
 				client = NULL;
-				iter = m_removed.begin();	// reset iterator after changing list
 			}
+			else ++iter;
 		}
 	}
 	RemoveClosed(false);
@@ -797,13 +802,13 @@ bool StatusClient::ReadCommand(
 	/// should the command be echoed (also NeedEcho() has to be true)
 	bool echo,
 	/// timeout (ms) for read operation, 0 means infinite
-	int readTimeout
+	int timeout
 	)
 {
-	while (IsReadable(readTimeout)) {
+	while (IsReadable(timeout)) {
 		char byte;
-		int read = ReadChar();
-		switch (read)
+		int ch = ReadChar();
+		switch (ch)
 		{
 			case -1:
 				break; // read IAC or socket closed
@@ -818,7 +823,7 @@ bool StatusClient::ReadCommand(
 			case '\b':
 				if (m_currentCmd.GetLength()) {
 					m_currentCmd = m_currentCmd.Left(m_currentCmd.GetLength() - 1);
-					byte = char(read);
+					byte = char(ch);
 					if (echo && NeedEcho()) {
 						Write(&byte, 1);
 						Write(&" ", 1);
@@ -827,9 +832,11 @@ bool StatusClient::ReadCommand(
 				}
 				break;
 			default:
-				byte = char(read);
+				byte = char(ch);
 				m_currentCmd += byte;
 				cmd = m_currentCmd.Right(3);
+				// Note: this only works if the telnet client doesn't buffer characters
+				// Windows doesn't, my Linux telnet does
 				if (cmd == "\x1b\x5b\x41") { // Up Arrow
 					if (echo && NeedEcho()) {
 						for(PINDEX i = 0; i < m_currentCmd.GetLength() - 3; i ++)
@@ -861,7 +868,7 @@ bool StatusClient::WriteString(
 	if (m_isFilteringActive && (IsExcludeMessage(msg) || !IsIncludeMessage(msg)))
 	    return false;
 	
-	if (!WriteData(msg, msg.GetSize()))
+	if (!WriteData(msg, msg.GetLength()))
 	    while (CanFlush())
 		Flush();
 
@@ -978,7 +985,7 @@ void StatusClient::DoDebug(
 				PString result = "Config sections\r\n";
 				for (PINDEX i = 0; i < secs.GetSize(); i++)
 					result += "[" + secs[i] + "]\r\n";
-				WriteString(result);
+				WriteString(result + ";\r\n");
 			}
 		} else if ((args[1] *= "set") && (args.GetSize()>=5)) {
 			Toolkit::Instance()->SetConfig(1, args[2], args[3], args[4]);
@@ -1101,6 +1108,12 @@ PString StatusClient::GetPassword(
 		? Toolkit::Instance()->ReadPassword(authsec, login, true) : PString();
 }
 
+void StatusClient::CommandError(const PString & msg)
+{
+	WriteString(msg + "\r\n");
+	PTRACE(2, "STATUS\t" + msg + " from client " << Name());
+}
+
 void StatusClient::ExecCommand(
 	/// the command to be executed
 	PString cmd
@@ -1117,38 +1130,30 @@ void StatusClient::ExecCommand(
 		// disconnect call on this IP number
 		if (args.GetSize() == 2)
 			SoftPBX::DisconnectIp(args[1]);
-		else {
-			WriteString("Syntax Error: DisconnectIp IP_ADDRESS\r\n");
-			PTRACE(2, "Syntax Error: DisconnectIp IP_ADDRESS");
-		}
+		else
+			CommandError("Syntax Error: DisconnectIp IP_ADDRESS");
 		break;
 	case GkStatus::e_DisconnectAlias:
 		// disconnect call on this alias
 		if (args.GetSize() == 2)
 			SoftPBX::DisconnectAlias(args[1]);
-		else {
-			WriteString("Syntax Error: DisconnectAlias ALIAS\r\n");
-			PTRACE(2, "Syntax Error: DisconnectAlias ALIAS");
-		}
+		else
+			CommandError("Syntax Error: DisconnectAlias ALIAS");
 		break;
 	case GkStatus::e_DisconnectCall:
 		// disconnect call with this call number
 		if (args.GetSize() >= 2)
 			for (PINDEX p=1; p < args.GetSize(); ++p)
 				SoftPBX::DisconnectCall(args[p].AsInteger());
-		else {
-			WriteString("Syntax Error: DisconnectCall CALL_NUMBER [CALL_NUMBER...]\r\n");
-			PTRACE(2, "Syntax Error: DisconnectCall CALL_NUMBER [CALL_NUMBER...]");
-		}
+		else
+			CommandError("Syntax Error: DisconnectCall CALL_NUMBER [CALL_NUMBER...]");
 		break;
 	case GkStatus::e_DisconnectEndpoint:
 		// disconnect call on this alias
 		if (args.GetSize() == 2)
 			SoftPBX::DisconnectEndpoint(args[1]);
-		else {
-			WriteString("Syntax Error: DisconnectEndpoint ENDPOINT_IDENTIFIER\r\n");
-			PTRACE(2, "Syntax Error: DisconnectEndpoint ENDPOINT_IDENTIFIER");
-		}
+		else
+			CommandError("Syntax Error: DisconnectEndpoint ENDPOINT_IDENTIFIER");
 		break;
 	case GkStatus::e_DisconnectSession:
 		// disconnect a user from status port
@@ -1157,10 +1162,8 @@ void StatusClient::ExecCommand(
 				WriteString("Session " + args[1] + " disconnected\r\n");
 			else
 				WriteString("Session " + args[1] + " not found\r\n");
-		else {
-			WriteString("Syntax Error: DisconnectSession SESSION_ID\r\n");
-			PTRACE(2, "Syntax Error: DisconnectSession SESSION_ID");
-		}
+		else
+			CommandError("Syntax Error: DisconnectSession SESSION_ID");
 		break;
 	case GkStatus::e_ClearCalls:
 		SoftPBX::DisconnectAll();
@@ -1191,18 +1194,14 @@ void StatusClient::ExecCommand(
 	case GkStatus::e_Find:
 		if (args.GetSize() == 2)
 			SoftPBX::PrintEndpoint(args[1], this, FALSE);
-		else {
-			WriteString("Syntax Error: Find ALIAS\r\n");
-			PTRACE(2, "Syntax Error: Find ALIAS");
-		}
+		else
+			CommandError("Syntax Error: Find ALIAS");
 		break;
 	case GkStatus::e_FindVerbose:
 		if (args.GetSize() == 2)
 			SoftPBX::PrintEndpoint(args[1], this, TRUE);
-		else {
-			WriteString("Syntax Error: FindVerbose ALIAS\r\n");
-			PTRACE(2, "Syntax Error: FindVerbose ALIAS");
-		}
+		else
+			CommandError("Syntax Error: FindVerbose ALIAS");
 		break;
 	case GkStatus::e_Yell:
 		m_gkStatus->SignalStatus(PString("  "+ WhoAmI() + ": " + cmd + "\r\n"));
@@ -1228,41 +1227,33 @@ void StatusClient::ExecCommand(
 		break;
 	case GkStatus::e_UnregisterAllEndpoints:
 		SoftPBX::UnregisterAllEndpoints();
-		WriteString("Done\n;\n");
+		WriteString("Done\r\n;\r\n");
 		break;
 	case GkStatus::e_UnregisterAlias:
 		// unregister this alias
 		if (args.GetSize() == 2)
 			SoftPBX::UnregisterAlias(args[1]);
-		else {
-			WriteString("Syntax Error: UnregisterAlias ALIAS\r\n");
-			PTRACE(2, "Syntax Error: UnregisterAlias ALIAS");
-		}
+		else
+			CommandError("Syntax Error: UnregisterAlias ALIAS");
 		break;
 	case GkStatus::e_UnregisterIp:
 		// unregister this IP
 		if (args.GetSize() == 2)
 			SoftPBX::UnregisterIp(args[1]);
-		else {
-			WriteString("Syntax Error: UnregisterIp IP_ADDRESS\r\n");
-			PTRACE(2, "Syntax Error: UnregisterIp IP_ADDRESS");
-		}
+		else
+			CommandError("Syntax Error: UnregisterIp IP_ADDRESS");
 		break;
 	case GkStatus::e_TransferCall:
 		if (args.GetSize() == 3)
 			SoftPBX::TransferCall(args[1], args[2]);
-		else {
-			WriteString("Syntax Error: TransferCall SOURCE DESTINATION\r\n");
-			PTRACE(2, "Syntax Error: TransferCall SOURCE DESTINATION");
-		}
+		else
+			CommandError("Syntax Error: TransferCall SOURCE DESTINATION");
 		break;
 	case GkStatus::e_MakeCall:
 		if (args.GetSize() == 3)
 			SoftPBX::MakeCall(args[1], args[2]);
-		else {
-			WriteString("Syntax Error: MakeCall SOURCE DESTINATION\r\n");
-			PTRACE(2, "Syntax Error: MakeCall SOURCE DESTINATION");
-		}
+		else
+			CommandError("Syntax Error: MakeCall SOURCE DESTINATION");
 		break;
 	case GkStatus::e_Reload:
 		{
@@ -1275,24 +1266,31 @@ void StatusClient::ExecCommand(
 		break;
 	case GkStatus::e_Shutdown:
 		if (!Toolkit::AsBool(GkConfig()->GetString(authsec, "Shutdown", "1"))) {
-			WriteString("Shutdown not allowed!\r\n");
-			PTRACE(2, "Shutdown not allowed!");
+			CommandError("Shutdown not allowed!");
 			break;
 		}
 		SoftPBX::PrintStatistics(this, true);
 		RasServer::Instance()->Stop();
 		break;
+	case GkStatus::e_SendProceeding:
+		if (args.GetSize() == 2) {
+			SoftPBX::SendProceeding(args[1]);
+		} else
+			CommandError("Syntax Error: SendProceeding CALLID");
+		break;
 	case GkStatus::e_RouteToAlias:
 		if (args.GetSize() == 4) {
+			if (args[1] == "-")
+				args[1] = "";	// "-" is empty agent
 			RasServer::Instance()->GetVirtualQueue()->RouteToAlias(args[1], "", args[2], args[3].AsUnsigned(), "");
 		} else if (args.GetSize() == 5) {
+			if (args[1] == "-")
+				args[1] = "";	// "-" is empty agent
 			args[4].Replace("-", " ", true);
 			args[4] = args[4].Trim();
 			RasServer::Instance()->GetVirtualQueue()->RouteToAlias(args[1], "", args[2], args[3].AsUnsigned(), args[4]);
-		} else {
-			WriteString("Syntax Error: RouteToAlias TARGET_ALIAS CALLING_ENDPOINT_ID CRV [CALLID]\r\n");
-			PTRACE(2, "Syntax Error: RouteToAlias TARGET_ALIAS CALLING_ENDPOINT_ID CRV [CALLID]");
-		}
+		} else
+			CommandError("Syntax Error: RouteToAlias TARGET_ALIAS CALLING_ENDPOINT_ID CRV [CALLID]");
 		break;
 	case GkStatus::e_RouteToGateway:
 		if (args.GetSize() == 5) {
@@ -1301,10 +1299,8 @@ void StatusClient::ExecCommand(
 			args[5].Replace("-", " ", true);
 			args[5] = args[5].Trim();
 			RasServer::Instance()->GetVirtualQueue()->RouteToAlias(args[1], args[2], args[3], args[4].AsUnsigned(), args[5]);
-		} else {
-			WriteString("Syntax Error: RouteToGateway TARGET_ALIAS TARGET_IP CALLING_ENDPOINT_ID CRV [CALLID]\r\n");
-			PTRACE(2, "Syntax Error: RouteToGateway TARGET_ALIAS TARGET_IP CALLING_ENDPOINT_ID CRV [CALLID]");
-		}
+		} else
+			CommandError("Syntax Error: RouteToGateway TARGET_ALIAS TARGET_IP CALLING_ENDPOINT_ID CRV [CALLID]");
 		break;
 	case GkStatus::e_RouteReject:
 		if (args.GetSize() == 3) {
@@ -1313,10 +1309,8 @@ void StatusClient::ExecCommand(
 			args[3].Replace("-", " ", true);
 			args[3] = args[3].Trim();
 			RasServer::Instance()->GetVirtualQueue()->RouteReject(args[1], args[2].AsUnsigned(), args[3]);
-		} else {
-			WriteString("Syntax Error: RouteReject CALLING_ENDPOINT_ID CRV [CALLID]\r\n");
-			PTRACE(2, "Syntax Error: RouteReject CALLING_ENDPOINT_ID CRV [CALLID]");
-		}
+		} else
+			CommandError("Syntax Error: RouteReject CALLING_ENDPOINT_ID CRV [CALLID]");
 		break;
 	case GkStatus::e_Trace:
 		if (args.GetSize() == 2) {
@@ -1330,8 +1324,7 @@ void StatusClient::ExecCommand(
 					&& level <= MAX_STATUS_TRACE_LEVEL)
 					m_traceLevel = level;
 				else {
-					WriteString("Syntax Error: trace 0|1|2|\"min\"|\"max\"\r\n");
-					PTRACE(2, "Syntax Error: trace 0|1|2|\"min\"|\"max\"");
+					CommandError("Syntax Error: trace 0|1|2|\"min\"|\"max\"");
 					break;
 				}
 			}
@@ -1351,65 +1344,51 @@ void StatusClient::ExecCommand(
 		if (args.GetSize() == 2) {
 			if (Gatekeeper::SetLogFilename(args[1])) {
 				WriteString("Logging to the file '" + args[1] + "'\r\n");
-			} else {					
-				WriteString("Failed to open the log file'" + args[1] + "'\r\n");
-				PTRACE(2, "Failed to open the log file'" + args[1] + "'");
-			}
-		} else {
-			WriteString("Syntax Error: setlog <logfilepath>\r\n");
-			PTRACE(2, "Syntax Error: setlog <logfilepath>");
-		}
+			} else
+				CommandError("Failed to open the log file'" + args[1] + "'");
+		} else
+			CommandError("Syntax Error: setlog <logfilepath>");
 		break;				
 #endif
 
 	case GkStatus::e_AddIncludeFilter:
 	    if (args.GetSize() == 2) {
-		AddFilter(m_includeFilterRegex, args[1]);
-	    } else {
-			WriteString("Syntax Error: addincludefilter REGEX\r\n");
-			PTRACE(2, "Syntax Error: addincludefilter REGEX");
-		}
+			AddFilter(m_includeFilterRegex, args[1]);
+	    } else
+			CommandError("Syntax Error: addincludefilter REGEX");
 	    break;
 	case GkStatus::e_RemoveIncludeFilter:
 	    if (args.GetSize() == 2) {
-		RemoveFilter(m_includeFilterRegex, atoi(args[1]));
-	    } else {
-			WriteString("Syntax Error: removeincludefilter FILTER_INDEX\r\n");
-			PTRACE(2, "Syntax Error: removeincludefilter FILTER_INDEX");
-		}
+			RemoveFilter(m_includeFilterRegex, atoi(args[1]));
+	    } else
+			CommandError("Syntax Error: removeincludefilter FILTER_INDEX");
 	    break;
 	case GkStatus::e_AddExcludeFilter:
 	    if (args.GetSize() == 2) {
-		AddFilter(m_excludeFilterRegex, args[1]);
-	    } else {
-			WriteString("Syntax Error: addexcludefilter REGEX\r\n");
-			PTRACE(2, "Syntax Error: addexcludefilter REGEX");
-		}
+			AddFilter(m_excludeFilterRegex, args[1]);
+	    } else
+			CommandError("Syntax Error: addexcludefilter REGEX");
 	    break;
 	case GkStatus::e_RemoveExcludeFilter:
 	    if (args.GetSize() == 2) {
-		RemoveFilter(m_excludeFilterRegex, atoi(args[1]));
-	    } else {
-			WriteString("Syntax Error: removeincludefilter FILTER_INDEX\r\n");
-			PTRACE(2, "Syntax Error: removeincludefilter FILTER_INDEX");
-		}
+			RemoveFilter(m_excludeFilterRegex, atoi(args[1]));
+	    } else
+			CommandError("Syntax Error: removeincludefilter FILTER_INDEX");
 	    break;
 	case GkStatus::e_Filter:
 	    if (args.GetSize() == 2) {
-		if (!(args[1] *= "0") && !(args[1] *= "1")) {
-		    WriteString("Syntax Error: filter 0|1\r\n");
-			PTRACE(2, "Syntax Error: filter 0|1");
-		    break;
-		}
-		m_isFilteringActive = Toolkit::AsBool(args[1]);
+			if (!(args[1] *= "0") && !(args[1] *= "1")) {
+				CommandError("Syntax Error: filter 0|1");
+				break;
+			}
+			m_isFilteringActive = Toolkit::AsBool(args[1]);
 	    }
 	    if (m_isFilteringActive) {
-		PString msg("Filtering is active\r\n");
-		WriteData(msg, msg.GetLength());
-	    }
-	    else {
-		PString msg("Filtering is not active\r\n");
-		WriteData(msg, msg.GetLength());
+			PString msg("Filtering is active\r\n");
+			WriteData(msg, msg.GetLength());
+	    } else {
+			PString msg("Filtering is not active\r\n");
+			WriteData(msg, msg.GetLength());
 	    }
 	    break;
 	case GkStatus::e_PrintExcludeFilters:
@@ -1418,10 +1397,20 @@ void StatusClient::ExecCommand(
 	case GkStatus::e_PrintIncludeFilters:
 	    PrintFilters(m_includeFilterRegex);
 	    break;
+	case GkStatus::e_PrintPrefixCapacities:
+		if (args.GetSize() == 1)
+			SoftPBX::PrintPrefixCapacities(this, "");
+		else if (args.GetSize() == 2)
+			SoftPBX::PrintPrefixCapacities(this, args[1]);
+		else
+			CommandError("Syntax Error: PrintPrefixCapacities [ALIAS]");
+		break;
+	case GkStatus::e_PrintCapacityControlRules:
+		SoftPBX::PrintCapacityControlRules(this);
+		break;
 	default:
 		// commmand not recognized
-		WriteString("Error: Unknown command " + cmd + "\r\n");
-		PTRACE(2, "STATUS\tUnknown command '" << cmd << "' from client " << Name());
+		CommandError("Error: Unknown command '" + cmd + "'");
 		break;
 	}
 	PWaitAndSignal lock(m_cmutex);
@@ -1442,24 +1431,16 @@ void StatusClient::RemoveFilter(
     // vector of filters
     std::vector<PString>& regexFilters,
     // Index of filter to be removed
-    const PINDEX index
+    unsigned int index
     )
 {
-    if (index < 0 || index >= (PINDEX) regexFilters.size()) {
+    if (index < 0 || index >= regexFilters.size()) {
 		PString msg("Index mismatch.\r\n");
 		WriteData(msg, msg.GetLength());
 		return;
     }
 
-    std::vector<PString>::iterator it = regexFilters.begin();
-
-    PINDEX i = 0;
-    while(i != index) {
-		++it;
-		++i;
-    }
-
-    regexFilters.erase(it);
+    regexFilters.erase(regexFilters.begin() + index);
 }
 
 bool StatusClient::IsExcludeMessage(
@@ -1478,11 +1459,10 @@ bool StatusClient::MatchFilter(
     ) const
 {
     std::vector<PString>::const_iterator it = regexFilters.begin();
-    std::vector<PString>::const_iterator itEnd = regexFilters.end();
 
-    for(; it != itEnd; ++it) {
-	if (Toolkit::MatchRegex(msg, *it))
-	    return true;
+    for(; it != regexFilters.end(); ++it) {
+		if (Toolkit::MatchRegex(msg, *it))
+			return true;
     }
 
     return false;
@@ -1501,24 +1481,19 @@ void StatusClient::PrintFilters(
     std::vector<PString>& regexFilters
     )
 {
-    std::vector<PString>::const_iterator it = regexFilters.begin();
-    std::vector<PString>::const_iterator itEnd = regexFilters.end();
-    unsigned int index = 0;
-    PString count;
+	PString msg;
 
-    if (regexFilters.size() == 0) {
-		PString msg("No Filters are defined\r\n");
+    if (regexFilters.empty()) {
+		msg = "No Filters are defined\r\n";
 		WriteData(msg, msg.GetLength());
 		return;
     }
 
-    PString msg("Filter List:\r\n");
+    msg = "Filter List:\r\n";
     WriteData(msg, msg.GetLength());
-    for(; it != itEnd; ++it, ++index) {
-		count = index;
-		PString item(count);
-		item += ") " + *it + "\r\n";
-		WriteData(item, item.GetLength());
+    for(unsigned int index = 0; index < regexFilters.size(); index++) {
+		msg = PString(index) + ") " + regexFilters[index] + "\r\n";
+		WriteData(msg, msg.GetLength());
     }
     
     msg = ";\r\n";
@@ -1528,12 +1503,12 @@ void StatusClient::PrintFilters(
 // class StatusListener
 StatusListener::StatusListener(
 	const Address& addr, 
-	WORD port
+	WORD lport
 	)
 {
 	const unsigned queueSize = GkConfig()->GetInteger("ListenQueueLength", GK_DEF_LISTEN_QUEUE_LENGTH);
-	if (!Listen(addr, queueSize, port, PSocket::CanReuseAddress)) {
-		PTRACE(1, "STATUS\tCould not open listening socket at " << addr << ':' << port
+	if (!Listen(addr, queueSize, lport, PSocket::CanReuseAddress)) {
+		PTRACE(1, "STATUS\tCould not open listening socket at " << addr << ':' << lport
 			<< " - error " << GetErrorCode(PSocket::LastGeneralError) << '/'
 			<< GetErrorNumber(PSocket::LastGeneralError) << ": " 
 			<< GetErrorText(PSocket::LastGeneralError)
