@@ -11,7 +11,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef GKSTATUS_H
-#define GKSTATUS_H "@(#) $Id: GkStatus.h,v 1.24 2007/03/21 22:30:16 willamowius Exp $"
+#define GKSTATUS_H "@(#) $Id: GkStatus.h,v 1.28 2008/01/22 16:08:58 willamowius Exp $"
 
 #include <map>
 #include "yasocket.h"
@@ -122,21 +122,24 @@ public:
 		e_Exit,                        /// Close Connection
 		e_Reload,                      /// Reload Config File
 		e_Shutdown,                    /// Shutdown the program
-		e_RouteToAlias,                /// Route a call upon ARQ to a specified alias eg. a free CTI agent
-		e_RouteToGateway,              /// Route a call upon ARQ to a specified alias + destinationCallSignalAddr
+		e_RouteToAlias,                /// Route a call to a specified alias
+		e_RouteToGateway,              /// Route a call to a specified alias + destinationCallSignalAddr
 		e_RouteReject,                 /// Reject to Route a call upon ARQ (send ARJ)
 		e_Trace,                       /// change trace level for status interface output
 #if PTRACING
 		e_RotateLog,                   /// Force log file rotation
 		e_SetLogFilename,              /// Change log file location
 #endif
-		e_AddIncludeFilter,            /// Add includse filter
+		e_AddIncludeFilter,            /// Add include filter
 		e_RemoveIncludeFilter,         /// Remove include filter
 		e_AddExcludeFilter,            /// Add exclude filter
 		e_RemoveExcludeFilter,         /// Remove exclude filter
 		e_Filter,                      /// Activate Status Port filtering
 		e_PrintExcludeFilters,         /// Print list of all exclude filters
 		e_PrintIncludeFilters,         /// Print list of all include filters
+		e_PrintPrefixCapacities,       /// Print prefix capacity settings with their current counters
+		e_PrintCapacityControlRules,   /// Print CapacityControl rules and their current capacities
+		e_SendProceeding,              /// Send a CallProceeding message for this call-id
 		e_numCommands
 		/// Number of different strings
 	};
