@@ -15,12 +15,16 @@
 //////////////////////////////////////////////////////////////////
 
 #if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
+  #pragma warning(disable:4786) // warning about too long debug symbol off
+  #pragma warning(disable:4284)
+#endif
+#if defined(_WIN32) && (_MSC_VER > 1300)
+  #pragma warning(disable:4244) // warning about possible loss of data
 #endif
 
 #include <ptlib.h>
 #include <ptclib/pdns.h>
+#include <ptclib/enum.h>
 #include <h323pdu.h>
 #include <ptclib/cypher.h>
 #include "gk_const.h"
@@ -29,12 +33,16 @@
 #include "RasPDU.h"
 #include "RasSrv.h"
 #include "RasTbl.h"
-#include "Routing.h"
 #include "sigmsg.h"
 #include "cisco.h"
+#include "h323util.h"
 #include "Neighbor.h"
 #include "pwlib_compat.h"
 
+#ifdef hasH460
+  #include <h460/h4601.h>
+#endif
+
 using std::multimap;
 using std::make_pair;
 using std::find_if;
@@ -476,6 +484,19 @@ bool GnuGK::OnSendingLRQ(H225_LocationRequest & lrq, const AdmissionRequest & re
 		lrq.IncludeOptionalField(H225_LocationRequest::e_canMapAlias);
 		lrq.m_canMapAlias = arq.m_canMapAlias;
 	}
+
+#ifdef hasH460
+       lrq.IncludeOptionalField(H225_LocationRequest::e_genericData); 
+       H225_ArrayOf_GenericData & data = lrq.m_genericData;
+       PINDEX lastPos = 0;
+
+	   /// OID9  'Remote application info
+	   H460_FeatureOID foid9 = H460_FeatureOID(OID9);
+	   lastPos++;
+	   data.SetSize(lastPos);
+	   data[lastPos-1] = foid9;
+	     		
+#endif
 	return true;
 }
 
@@ -569,7 +590,7 @@ bool CiscoGK::OnSendingLRQ(H225_LocationRequest &lrq, const AdmissionRequest &re
 }
 
 // class CiscoGK
-bool CiscoGK::OnSendingLRQ(H225_LocationRequest &lrq, const LocationRequest &req)
+bool CiscoGK::OnSendingLRQ(H225_LocationRequest &lrq, const LocationRequest & /*req*/)
 {
 	if (lrq.HasOptionalField(H225_LocationRequest::e_nonStandardData)
 			&& lrq.m_nonStandardData.GetTag() == H225_NonStandardIdentifier::e_h221NonStandard) {
@@ -926,17 +947,16 @@ void NeighborList::OnReload()
 	PINDEX i, sz = cfgs.GetSize();
 	List::iterator iter = m_neighbors.begin();
 	while (iter != m_neighbors.end()) {
-		List::iterator it = iter++;
 		for (i = 0; i < sz; ++i)
-			if ((*it)->GetId() == cfgs.GetKeyAt(i))
+			if ((*iter)->GetId() == cfgs.GetKeyAt(i))
 				break;
 		if (i == sz) {
-			Neighbor * r = *it;
-			m_neighbors.erase(it);
+			Neighbor * r = *iter;
+			iter = m_neighbors.erase(iter);
 			delete r;
 			r = NULL;
-			iter = m_neighbors.begin();	// reset iterator after changing container
 		}
+		else ++iter;
 	}
 	for (i = 0; i < sz; ++i) {
 		const PString & nbid = cfgs.GetKeyAt(i);
@@ -1119,6 +1139,15 @@ bool NeighborPolicy::OnRequest(AdmissionRequest & arq_obj)
 	if (request.Send(m_neighbors)) {
 		if (H225_LocationConfirm *lcf = request.WaitForDestination(m_neighborTimeout)) {
 			Route route(m_name, lcf->m_callSignalAddress);
+#ifdef hasH460
+			if (lcf->HasOptionalField(H225_LocationConfirm::e_genericData)) {
+			  H225_RasMessage ras;
+			  ras.SetTag(H225_RasMessage::e_locationConfirm);
+              H225_LocationConfirm & con = (H225_LocationConfirm &)ras;
+			  con = *lcf;
+			  route.m_destEndpoint = endptr(new EndpointRec(ras));	
+			}
+#endif
 			route.m_routeId = request.GetNeighborUsed();
 			route.m_flags |= Route::e_toNeighbor;
 			if ((lcf->HasOptionalField(H225_LocationConfirm::e_destinationInfo))
@@ -1266,7 +1295,9 @@ public:
 	SRVPolicy() { m_name = "SRV"; }
 
 protected:
-	// override from class Policy
+    virtual bool OnRequest(SetupRequest &) { return false; }
+    virtual bool OnRequest(FacilityRequest &) { return false; }
+
 	virtual bool FindByAliases(RoutingRequest &, H225_ArrayOf_AliasAddress &);
 	virtual bool FindByAliases(LocationRequest &, H225_ArrayOf_AliasAddress &);
 
@@ -1319,8 +1350,25 @@ bool SRVPolicy::FindByAliases(
 				if (Request.Send(nb)) {
 					if (H225_LocationConfirm *lcf = Request.WaitForDestination(m_neighborTimeout)) {
 							Route route(m_name, lcf->m_callSignalAddress);
+#ifdef hasH460
+			                if (lcf->HasOptionalField(H225_LocationConfirm::e_genericData)) {
+			                    H225_RasMessage ras;
+			                    ras.SetTag(H225_RasMessage::e_locationConfirm);
+                                H225_LocationConfirm & con = (H225_LocationConfirm &)ras;
+			                    con = *lcf;
+			                    route.m_destEndpoint = endptr(new EndpointRec(ras));	
+			                }
+#endif
 							request.AddRoute(route);
-							request.SetFlag(RoutingRequest::e_aliasesChanged);
+                             // Fix for calling only a numeric number so the @xxx is removed
+				             PString called = ls[i].Left(at);
+						     PINDEX k = 0;
+						     for (k = 0; k < called.GetLength(); ++k)
+								if (!isdigit(alias[k]))
+									break;
+								if (k >= alias.GetLength())
+									H323SetAliasAddress(called, aliases[i]);
+							 request.SetFlag(RoutingRequest::e_aliasesChanged);
 							return true;
 				    }
 				}
@@ -1341,6 +1389,14 @@ bool SRVPolicy::FindByAliases(
 			       if (!(GetIPFromTransportAddr(dest, addr) && addr.IsValid()))
 				                    continue;
 			       Route route(m_name, dest);
+                    // Fix for calling only a numeric number so the @xxx is removed
+				     PString called = cs[j].Left(in);
+					  PINDEX l = 0;
+						for (l = 0; l < called.GetLength(); ++l)
+							if (!isdigit(alias[l]))
+								break;
+						if (l >= alias.GetLength())
+						  H323SetAliasAddress(called, aliases[i]);
 			       route.m_destEndpoint = RegistrationTable::Instance()->FindBySignalAdr(dest);
 			       request.AddRoute(route);
 			       request.SetFlag(RoutingRequest::e_aliasesChanged);	
@@ -1360,12 +1416,109 @@ bool SRVPolicy::FindByAliases(LocationRequest & request, H225_ArrayOf_AliasAddre
 }
 #endif
 
+///////////////////////////////////////////////////////////////////////////////////////////
+// RDS policy
+#ifdef hasRDS
+
+class RDSPolicy : public AliasesPolicy {
+public:
+	RDSPolicy() { m_name = "RDS"; }
+
+protected:
+    virtual bool OnRequest(SetupRequest &) { return false; }
+    virtual bool OnRequest(FacilityRequest &) { return false; }
+
+	virtual bool FindByAliases(RoutingRequest &, H225_ArrayOf_AliasAddress &);
+	virtual bool FindByAliases(LocationRequest &, H225_ArrayOf_AliasAddress &);
+
+private:
+	int m_Timeout;
+};
+
+bool RDSPolicy::FindByAliases(
+	RoutingRequest &request,
+	H225_ArrayOf_AliasAddress &aliases
+	)
+{
+	for (PINDEX a = 0; a < aliases.GetSize(); ++a) {
+		PString alias(AsString(aliases[a], FALSE));
+	    if (alias.GetLength() == 0) continue;
+
+	// DNS RDS Record lookup
+		PString number;
+		PString domain;
+		PINDEX at = alias.Find('@');
+		if (at == P_MAX_INDEX) {
+		   number = "h323:t@" + alias;	
+		   domain = alias;
+	    } else {
+		   number = "h323:" + alias;
+		   domain = alias.Mid(at+1);
+		}
+	
+		// LS Record lookup
+		PStringList ls;
+		 if (PDNS::RDSLookup(number,"H323+D2U",ls)) {
+			 for (PINDEX i=0; i<ls.GetSize(); i++) {
+				PINDEX pos = ls[i].Find('@');
+				PString ipaddr = ls[i].Mid(pos + 1);
+				PTRACE(4, "ROUTING\tRDS LS located domain " << domain << " at " << ipaddr);
+				H323TransportAddress addr = H323TransportAddress(ipaddr);
+
+				// Create a RDS gatekeeper object
+				GnuGK * nb = new GnuGK();
+				if (!nb->SetProfile(domain,addr)) {
+					PTRACE(4, "ROUTING\tERROR setting RDS neighbor profile " << domain << " at " << addr);
+					return false;
+				}
+
+				int m_neighborTimeout = GkConfig()->GetInteger(LRQFeaturesSection, "NeighborTimeout", 5) * 100;
+
+				// Send LRQ to retreive callers signalling address 
+				LRQSender<AdmissionRequest> functor((AdmissionRequest &)request);
+				LRQRequester Request(functor);
+				if (Request.Send(nb)) {
+					if (H225_LocationConfirm *lcf = Request.WaitForDestination(m_neighborTimeout)) {
+							Route route(m_name, lcf->m_callSignalAddress);
+#ifdef hasH460
+			                if (lcf->HasOptionalField(H225_LocationConfirm::e_genericData)) {
+			                    H225_RasMessage ras;
+			                    ras.SetTag(H225_RasMessage::e_locationConfirm);
+                                H225_LocationConfirm & con = (H225_LocationConfirm &)ras;
+			                    con = *lcf;
+			                    route.m_destEndpoint = endptr(new EndpointRec(ras));	
+			                }
+#endif
+							request.AddRoute(route);
+							request.SetFlag(RoutingRequest::e_aliasesChanged);
+							return true;
+				    }
+				}
+				PTRACE(4, "ROUTING\tDNS RDS LRQ Error for " << domain << " at " << ipaddr);
+			 }
+			}  
+	} 
+  return false; 
+}
+
+
+bool RDSPolicy::FindByAliases(LocationRequest & /* request */, H225_ArrayOf_AliasAddress & /* aliases */)
+{ 
+    PTRACE(4, "ROUTING\tPolicy RDS not supported for LRQ");
+	return false;  
+}
+#endif
+
 namespace {
 	SimpleCreator<NeighborPolicy> NeighborPolicyCreator("neighbor");
 
 #ifdef hasSRV
 	SimpleCreator<SRVPolicy> SRVPolicyCreator("srv");
 #endif
+
+#ifdef hasRDS
+	SimpleCreator<RDSPolicy> RDSPolicyCreator("rds");
+#endif
 }
 
 
