@@ -15,7 +15,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef PROXYCHANNEL_H
-#define PROXYCHANNEL_H "@(#) $Id: ProxyChannel.h,v 1.47 2006/09/16 20:42:50 shorne Exp $"
+#define PROXYCHANNEL_H "@(#) $Id: ProxyChannel.h,v 1.56 2008/02/20 08:47:06 willamowius Exp $"
 
 #include <vector>
 #include <list>
@@ -55,6 +55,13 @@ struct SetupAuthData;
 
 extern const char *RoutedSec;
 
+void PrintQ931(int, const char *, const char *, const Q931 *, const H225_H323_UserInformation *);
+
+bool GetUUIE(const Q931 & q931, H225_H323_UserInformation & uuie);
+
+void SetUUIE(Q931 & q931, const H225_H323_UserInformation & uuie);
+
+
 class ProxySocket : public USocket {
 public:
 	enum Result {
@@ -108,9 +115,9 @@ public:
 	PCLASSINFO( TCPProxySocket, ServerSocket )
 
 	// override from class PTCPSocket
-	virtual BOOL Accept(PSocket &);
-	virtual BOOL Connect(const Address &, WORD, const Address &);
-	virtual BOOL Connect(const Address &);
+	virtual PBoolean Accept(PSocket &);
+	virtual PBoolean Connect(const Address &, WORD, const Address &);
+	virtual PBoolean Connect(const Address &);
 #endif
 	// override from class ProxySocket
 	virtual bool ForwardData();
@@ -136,10 +143,14 @@ private:
 	BYTE *bufptr;
 };
 
+#if H323_H450
+class X880_Invoke;
+class H4501_InterpretationApdu;
+#endif
 class CallSignalSocket : public TCPProxySocket {
 public:
 	CallSignalSocket();
-	CallSignalSocket(CallSignalSocket *, WORD);
+	CallSignalSocket(CallSignalSocket *, WORD _port);
 	virtual ~CallSignalSocket();
 
 #ifdef LARGE_FDSET
@@ -148,7 +159,7 @@ public:
 #else
 	PCLASSINFO ( CallSignalSocket, TCPProxySocket )
 	// override from class TCPProxySocket
-	virtual BOOL Connect(const Address &);
+	virtual PBoolean Connect(const Address &);
 #endif
 
 	// override from class ProxySocket
@@ -167,6 +178,8 @@ public:
 	Address GetPeerAddr() { return peerAddr; }
 	Address GetMasqAddr() { return masqAddr; }
 	void BuildFacilityPDU(Q931 &, int, const PObject * = 0);
+	void BuildProgressPDU(Q931 &, PBoolean fromDestination);
+	void BuildProceedingPDU(Q931 & ProceedingPDU, const H225_CallIdentifier & callId, unsigned crv);
 	void RemoveCall();
 
 	// override from class ServerSocket
@@ -197,13 +210,18 @@ protected:
 	bool OnTunneledH245(H225_ArrayOf_PASN_OctetString &);
 	bool OnFastStart(H225_ArrayOf_PASN_OctetString &, bool);
 
+#if H323_H450
+	bool OnH450PDU(endptr &, H225_ArrayOf_PASN_OctetString &);
+	bool OnH450Invoke(endptr &, X880_Invoke &, H4501_InterpretationApdu &);
+	bool OnH450CallTransfer(endptr &, PASN_OctetString *);
+#endif
 
 	template<class UUIE> bool HandleH245Address(UUIE & uu)
 	{
 		if (uu.HasOptionalField(UUIE::e_h245Address)) {
-			if (m_call)
+			 if (m_call)
 				m_call->SetH245ResponseReceived();
-			if (SetH245Address(uu.m_h245Address))
+			 if (SetH245Address(uu.m_h245Address))
 				return (m_h245handler != 0);
 			uu.RemoveOptionalField(UUIE::e_h245Address);
 			return true;
