@@ -21,6 +21,7 @@
 
 #include <ptlib.h>
 #include <ptlib/sockets.h>
+#include <ptclib/enum.h>
 #include <h225.h>
 #include <h323pdu.h>
 #include "gk.h"
@@ -34,6 +35,7 @@
 #include "GkStatus.h"
 #include "Neighbor.h"
 #include "ProxyChannel.h"
+#include "h323util.h"
 #include "gkauth.h"
 #include "gkacct.h"
 #include "gktimer.h"
@@ -41,7 +43,7 @@
 #include "pwlib_compat.h"
 
 #ifdef hasH460
-  #include <h4601.h>
+  #include <h460/h4601.h>
 #endif
 
 const char *LRQFeaturesSection = "RasSrv::LRQFeatures";
@@ -50,7 +52,7 @@ using namespace std;
 using Routing::Route;
 
 #ifndef NEED_BROADCASTLISTENER
-#if (defined P_LINUX) || (defined P_FREEBSD) || (defined P_HPUX9) || (defined P_SOLARIS)
+#if (defined P_LINUX) || (defined P_FREEBSD) || (defined P_HPUX9) || (defined P_SOLARIS) || (defined P_OPENBSD)
 // On some OS we don't get broadcasts on a socket that is
 // bound to a specific interface. For those we have to start
 // a listener just for those broadcasts.
@@ -210,7 +212,7 @@ RasListener::RasListener(const Address & addr, WORD pt) : m_ip(addr)
 			);
 		Close();
 	}
-	SetWriteTimeout(1000); // TODO: read from config
+	SetWriteTimeout(1000);
 	SetName(AsString(addr, pt) + "(U)");
 	m_signalPort = 0;
 	// note: this won't be affected by reloading
@@ -271,7 +273,7 @@ bool RasListener::SendRas(const H225_RasMessage & rasobj, const Address & addr,
 	return result;
 }
 
-PIPSocket::Address RasListener::GetPhysicalAddr(const Address & addr) const
+PIPSocket::Address RasListener::GetPhysicalAddr(const Address & /* addr */) const
 {
 	// Return the physical address. This is used when setting sockets
 	return m_ip;
@@ -697,7 +699,6 @@ RasServer::RasServer() : Singleton<RasServer>("RasSrv"), requestSeqNum(0),
 
 RasServer::~RasServer()
 {
-	delete vqueue;
 	delete authList;
 	delete acctList;
 	delete neighbors;
@@ -711,6 +712,7 @@ void RasServer::Stop()
 	PTRACE(1, "GK\tStopping RasServer...");
 	PWaitAndSignal lock(m_deletionPreventer);
 	ForEachInContainer(handlers, mem_vfun(&RasHandler::Stop));
+	delete vqueue;	// delete virtual queues before Jobs, otherwise the jobs will wait for the queues
 	RegularJob::Stop();
 }
 
@@ -748,6 +750,44 @@ void RasServer::SetRoutedMode(bool routedSignaling, bool routedH245)
 #endif
 }
 
+void RasServer::SetENUMServers()
+{
+#if hasSETENUMSERVERS
+  PString servers = GkConfig()->GetString(RoutedSec, "ENUMservers", "");
+  PStringArray serverlist(servers.Tokenise(",", false));
+
+  if (serverlist.GetSize() > 0) {
+	   PDNS::SetENUMServers(serverlist);
+       PTRACE(2, "GK\tLoaded ENUM servers " << serverlist);
+  } else {
+	   PTRACE(2, "GK\tNo ENUMservers set, using defaults");
+  }
+#else
+#if P_DNS
+	   PTRACE(2, "GK\tSetENUMServers not available, using defaults");
+#else
+	   PTRACE(2, "GK\tNo ENUM Routing policy available.");
+#endif
+#endif
+}
+
+void RasServer::SetRDSServers()
+{
+#if hasRDS
+  PString servers = GkConfig()->GetString(RoutedSec, "RDSservers", "");
+  PStringArray serverlist(servers.Tokenise(",", false));
+
+  if (serverlist.GetSize() > 0) {
+	   PDNS::SetRDSServers(serverlist);
+       PTRACE(2, "GK\tLoaded RDS servers " << serverlist);
+  } else {
+ 	   PTRACE(2, "GK\tNo RDSservers set, using defaults"); 	
+  }
+#else
+	   PTRACE(2, "GK\tNo RDS Routing policy available.");
+#endif
+}
+
 bool RasServer::AcceptUnregisteredCalls(const PIPSocket::Address & addr) const
 {
 	if (Toolkit::AsBool(GkConfig()->GetString(RoutedSec, "AcceptUnregisteredCalls", "0")))
@@ -790,20 +830,19 @@ void RasServer::LoadConfig()
 	}
 
 	SocketsReader::CleanUp();
-	ifiterator biter = interfaces.begin();
-	while (biter != interfaces.end()) {
-		ifiterator iter = biter++;
+	ifiterator it = interfaces.begin();
+	while (it != interfaces.end()) {
 		int i = -1;
 		while (++i < hsize)
-			if ((*iter)->IsBoundTo(&GKHome[i]))
+			if ((*it)->IsBoundTo(&GKHome[i]))
 				break;
 		if (i == hsize) {
 			// close unused listeners
-			GkInterface * r = *iter;
-			interfaces.erase(iter);
+			GkInterface * r = *it;
+			it = interfaces.erase(it);
 			delete r;
-			biter = interfaces.begin();
 		}
+		else ++it;
 	}
 	if (broadcastListener && !bUseBroadcastListener) {
 		broadcastListener->Close();
@@ -814,15 +853,15 @@ void RasServer::LoadConfig()
 
 	for (int i = 0; i < hsize; ++i) {
 		Address addr(GKHome[i]);
-		biter = interfaces.begin();
-		ifiterator iter = find_if(biter, interfaces.end(), bind2nd(mem_fun(&GkInterface::IsBoundTo), &addr));
+		ifiterator iter = find_if(interfaces.begin(), interfaces.end(), bind2nd(mem_fun(&GkInterface::IsBoundTo), &addr));
 		if (iter == interfaces.end()) {
 			GkInterface *gkif = CreateInterface(addr);
 			if (gkif->CreateListeners(this))
 				interfaces.push_back(gkif);
-			else
+			else {
 				delete gkif;
 				gkif = NULL;
+			}
 		} else {
 			GkInterface *gkif = *iter;
 			// re-create if changed
@@ -833,7 +872,7 @@ void RasServer::LoadConfig()
 			}
 		}
 	}
-	if (m_socksize == 0) {
+	if ((m_socksize == 0) || (interfaces.empty())) {
 		PTRACE(1, "Error: No valid RAS socket!");
 		return;
 	}
@@ -852,6 +891,7 @@ void RasServer::LoadConfig()
 	}
 #endif
 
+	listeners->LoadConfig();
 	gkClient->OnReload();
 	neighbors->OnReload();
 	authList->OnReload();
@@ -891,6 +931,8 @@ WORD RasServer::GetRequestSeqNum()
 GkInterface *RasServer::SelectInterface(const Address & addr)
 {
 	ifiterator iter, eiter = interfaces.end();
+	if (interfaces.empty())
+		return NULL;
 	iter = find_if(interfaces.begin(), eiter, bind2nd(mem_fun(&GkInterface::IsReachable), &addr));
 	return (iter != eiter) ? *iter : interfaces.front();
 }
@@ -922,8 +964,13 @@ H225_TransportAddress RasServer::GetCallSignalAddress(const Address & addr) cons
 
 bool RasServer::SendRas(const H225_RasMessage & rasobj, const Address & addr, WORD pt, RasListener *socket)
 {
-	if (socket == 0)
-		socket = SelectInterface(addr)->GetRasListener();
+	if (socket == 0) {
+		GkInterface * inter = SelectInterface(addr);
+		if (inter == NULL)
+			return false;
+		else
+			socket = inter->GetRasListener();
+	}
 	return socket->SendRas(rasobj, addr, pt);
 }
 
@@ -939,7 +986,13 @@ bool RasServer::SendRas(const H225_RasMessage & rasobj, const H225_TransportAddr
 
 bool RasServer::SendRas(const H225_RasMessage & rasobj, const Address & addr, WORD pt, const Address & local)
 {
-	return SelectInterface(local)->GetRasListener()->SendRas(rasobj, addr, pt);
+	GkInterface * inter = SelectInterface(local);
+	if (inter == NULL)
+		return false;
+	RasListener * listener = inter->GetRasListener();
+	if (listener == NULL)
+		return false;
+	return listener->SendRas(rasobj, addr, pt);
 }
 
 bool RasServer::IsRedirected(unsigned tag) const
@@ -1135,16 +1188,18 @@ void RasServer::Run()
 
 	LoadConfig();
 
-	callptr nullcall;
-	acctList->LogAcctEvent(GkAcctLogger::AcctOn,nullcall);
-	if (m_socksize > 0) {
+	if ((m_socksize > 0) && (!interfaces.empty())) {
+		callptr nullcall;
+		acctList->LogAcctEvent(GkAcctLogger::AcctOn,nullcall);
+
 		CreateJob(this, &RasServer::HouseKeeping, "HouseKeeping");
 		RegularJob::Run();
+
+		acctList->LogAcctEvent(GkAcctLogger::AcctOff,nullcall);
 	} else {
 		cerr << "FATAL: No valid interfaces to listen! Shutdown!" << endl;
 		PTRACE(0, "FATAL: No valid interfaces to listen! Shutdown!");
 	}
-	acctList->LogAcctEvent(GkAcctLogger::AcctOff,nullcall);
 }
 
 void RasServer::OnStop()
@@ -1352,7 +1407,7 @@ template<> bool RasPDU<H225_GatekeeperRequest>::Process()
 
 	PString log;
 	PString alias(request.HasOptionalField(H225_GatekeeperRequest::e_endpointAlias)
-		? AsString(request.m_endpointAlias) : PString(" ")
+		? AsString(request.m_endpointAlias[0],false) : PString(" ")
 		);
 
 	unsigned rsn = H225_GatekeeperRejectReason::e_securityDenial;
@@ -1380,10 +1435,19 @@ template<> bool RasPDU<H225_GatekeeperRequest>::Process()
 		GetRasAddress(gcf.m_rasAddress);
 		gcf.IncludeOptionalField(H225_GatekeeperConfirm::e_gatekeeperIdentifier);
 		gcf.m_gatekeeperIdentifier = Toolkit::GKName();
-		if (request.HasOptionalField(H225_GatekeeperRequest::e_supportsAltGK))
+
+#ifdef h323v6
+	    if (request.HasOptionalField(H225_GatekeeperRequest::e_supportsAssignedGK) &&
+            RasSrv->HasAssignedGK(alias,m_msg->m_peerAddr,gcf))
+			  PTRACE(2, "GCF\t" << alias << " redirected to assigned Gatekeeper");
+		else
+#endif
+		{
+		  if (request.HasOptionalField(H225_GatekeeperRequest::e_supportsAltGK))
 			RasSrv->SetAlternateGK(gcf);
 
-		RasSrv->SelectH235Capability(request, gcf);
+		  RasSrv->SelectH235Capability(request, gcf);
+		}
 
 		log = PString(PString::Printf, "GCF|%s|%s|%s;",
 			inet_ntoa(m_msg->m_peerAddr),
@@ -1431,10 +1495,10 @@ bool RegistrationRequestPDU::Process()
 
 ///////////////////////////////////////////////////////////////////////////////////////////
 // H460 support Code
-	BOOL supportNAT = false;
+	bool supportNAT = false;
 	int RegPrior =0;
 	bool preemptsupport = false;
-	BOOL preempt = false;
+	PBoolean preempt = false;
 
 #ifdef hasH460
 
@@ -1448,18 +1512,22 @@ bool RegistrationRequestPDU::Process()
 		if (fs.HasFeature(rPriFS)) {
 			H460_FeatureOID * feat = (H460_FeatureOID *)fs.GetFeature(rPriFS);
 			if (feat->Contains(priorityOID)) {
-				unsigned prior = feat->Value(priorityOID);
+				unsigned prior = feat->Value(PString(priorityOID));
 				RegPrior = (int)prior;  
 			}
 			if (feat->Contains(preemptOID)) {
 				preemptsupport = true;
-                preempt = feat->Value(preemptOID);
+                preempt = feat->Value(PString(preemptOID));
 			}
 		}
 	}
 #endif
 ///////////////////////////////////////////////////////////////////////////////////////////////
 
+   // If calling NAT support disabled. 
+   // Use this to block errant gateways that don't support NAT mechanism properly.
+	bool supportcallingNAT = Toolkit::AsBool(GkConfig()->GetString(RoutedSec, "SupportCallingNATedEndpoints", "1"));
+	
 	// lightweight registration update
 	if (request.HasOptionalField(H225_RegistrationRequest::e_keepAlive) && request.m_keepAlive) {
 		endptr ep = request.HasOptionalField(H225_RegistrationRequest::e_endpointIdentifier) ?
@@ -1489,7 +1557,7 @@ bool RegistrationRequestPDU::Process()
 					GetIPAndPortFromTransportAddr(ep->GetCallSignalAddress(), oaddr, oport),
 					raddr = oaddr, rport = oport;
 				}
-				 bReject = (oaddr != raddr) || (oport != rport) || (raddr != rx_addr);
+				bReject = (oaddr != raddr) || (oport != rport) || (IsLoopback(rx_addr) ? false : (raddr != rx_addr));
 			}
 		} 
 		if (bReject) {
@@ -1525,7 +1593,7 @@ bool RegistrationRequestPDU::Process()
 		for (int s = 0; s < request.m_callSignalAddress.GetSize(); ++s) {
 			SignalAddr = request.m_callSignalAddress[s];
 			if (GetIPFromTransportAddr(SignalAddr, ipaddr)) {
-				validaddress = (rx_addr == ipaddr);
+				validaddress = ((rx_addr == ipaddr) || IsLoopback(rx_addr));  
 				if (validaddress)
 					break;
 			}
@@ -1566,24 +1634,24 @@ bool RegistrationRequestPDU::Process()
 	if (request.HasOptionalField(H225_RegistrationRequest::e_terminalAlias) && (request.m_terminalAlias.GetSize() >= 1)) {
 		H225_ArrayOf_AliasAddress Alias, & Aliases = request.m_terminalAlias;
 		Alias.SetSize(1);
-		for (int i = 0; i < Aliases.GetSize(); ++i) {
-			Alias[0] = Aliases[i];
+		for (int a = 0; a < Aliases.GetSize(); ++a) {
+			Alias[0] = Aliases[a];
 			bool skip = false;
-			for (int j = 0; j < i; ++j) {
+			for (int j = 0; j < a; ++j) {
 				skip = (Alias[0] == Aliases[j]);
 				if (skip)
 					break;
 			}
 			if (skip) { // remove duplicate alias
-				Aliases.RemoveAt(i--);
+				Aliases.RemoveAt(a--);
 				continue;
 			}
 
 			const endptr ep = EndpointTbl->FindByAliases(Alias);
 			if (ep) {
-				bNewEP = ((ep->GetCallSignalAddress() != SignalAddr) || (preempt) || ((RegPrior > 0) && (RegPrior > ep->Priority())));
+				bNewEP = (ep->GetCallSignalAddress() != SignalAddr); 
 				if (bNewEP) {
-					if ((RegPrior > 0) || (preempt) ||
+					if ((RegPrior > ep->Priority()) || (preempt) ||
 					  (Toolkit::AsBool(Kit->Config()->GetString("RasSrv::RRQFeatures", "OverwriteEPOnSameAddress", "0")))) {
 						// If the operators policy allows this case:
 						// 1a) terminate all calls on active ep and
@@ -1610,7 +1678,7 @@ bool RegistrationRequestPDU::Process()
 						if ((preemptsupport) && (RegPrior == ep->Priority())) {  
 							rrj.IncludeOptionalField(H225_RegistrationReject::e_genericData);
 							H460_FeatureOID pre = H460_FeatureOID(rPriFS);
-                            pre.Add(preNotOID,H460_FeatureContent(TRUE));
+                            pre.Add(PString(preNotOID),H460_FeatureContent(TRUE));
 		                    H225_ArrayOf_GenericData & data = rrj.m_genericData;
 				               PINDEX lastPos = data.GetSize();
 				               data.SetSize(lastPos+1);
@@ -1651,15 +1719,25 @@ bool RegistrationRequestPDU::Process()
 	}
 
 	if (!nated && request.HasOptionalField(H225_RegistrationRequest::e_nonStandardData)) {
-		PString ipdata = request.m_nonStandardData.m_data.AsString();
-		if (strncmp(ipdata, "IP=", 3) == 0) {
-			PStringArray ips(ipdata.Mid(3).Tokenise(",:;", false));
-			PINDEX i;
-			for (i = 0; i < ips.GetSize(); ++i)
-				if (PIPSocket::Address(ips[i]) == rx_addr)
-					break;
-			nated = (i >= ips.GetSize());
-			request.RemoveOptionalField(H225_RegistrationRequest::e_nonStandardData);
+		int iec = Toolkit::iecUnknown;
+		if (request.m_nonStandardData.m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_h221NonStandard) {
+			iec = Toolkit::Instance()->GetInternalExtensionCode(request.m_nonStandardData.m_nonStandardIdentifier);
+		} else if (request.m_nonStandardData.m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_object) {
+			PASN_ObjectId &oid = request.m_nonStandardData.m_nonStandardIdentifier;
+			if (oid.GetDataLength() == 0)
+				iec = Toolkit::iecNATTraversal;
+		}
+		if (iec == Toolkit::iecNATTraversal) {
+			PString ipdata = request.m_nonStandardData.m_data.AsString();
+			if (strncmp(ipdata, "IP=", 3) == 0) {
+				PStringArray ips(ipdata.Mid(3).Tokenise(",:;", false));
+				PINDEX k;
+				for (k = 0; k < ips.GetSize(); ++k)
+					if (PIPSocket::Address(ips[k]) == rx_addr)
+						break;
+				nated = (k >= ips.GetSize());
+				request.RemoveOptionalField(H225_RegistrationRequest::e_nonStandardData);
+			}
 		}
 	}
 	request.m_callSignalAddress.SetSize(1);
@@ -1671,11 +1749,6 @@ bool RegistrationRequestPDU::Process()
 		return BuildRRJ(H225_RegistrationRejectReason::e_undefinedReason);
 	}
 
-#ifdef h323v6
-	if (request.HasOptionalField(H225_RegistrationRequest::e_assignedGatekeeper)) 
-             ep->SetAssignedGatekeeper(request.m_assignedGatekeeper);
-#endif
-
 	if (nated)
 		ep->SetNATAddress(rx_addr);
 	else {
@@ -1693,20 +1766,64 @@ bool RegistrationRequestPDU::Process()
 		//
 		BuildRCF(ep);
 		H225_RegistrationConfirm & rcf = m_msg->m_replyRAS;
-		if (nated) {
+		if (supportcallingNAT && nated) {
 			// tell the endpoint its translated address
 			rcf.IncludeOptionalField(H225_RegistrationConfirm::e_nonStandardData);
+		    rcf.m_nonStandardData.m_nonStandardIdentifier.SetTag(H225_NonStandardIdentifier::e_h221NonStandard);
+			H225_H221NonStandard &t35 = rcf.m_nonStandardData.m_nonStandardIdentifier;
+			t35.m_t35CountryCode = Toolkit::t35cPoland;
+			t35.m_manufacturerCode = Toolkit::t35mGnuGk;
+			t35.m_t35Extension = Toolkit::t35eNATTraversal;
 			rcf.m_nonStandardData.m_data = "NAT=" + rx_addr.AsString();
 		}
+
+#ifdef hasH460
+		   H225_ArrayOf_GenericData & gd = rcf.m_genericData;
+
+		   // if the client supports Registration PreEmption then notify the client that we do too
+		   if ((preemptsupport) &&
+			  (request.HasOptionalField(H225_RegistrationRequest::e_keepAlive) && (!request.m_keepAlive))) {
+              H460_FeatureOID pre = H460_FeatureOID(rPriFS);
+			  PINDEX lPos = gd.GetSize();
+			  gd.SetSize(lPos+1);
+			  gd[lPos] = pre;
+			}
+			if (gd.GetSize() > 0)		  
+				rcf.IncludeOptionalField(H225_RegistrationConfirm::e_genericData);
+#endif
+
+		// Gatekeeper assigned Aliases if the client supplied aliases
+		if (request.HasOptionalField(H225_RegistrationRequest::e_terminalAlias) &&
+			                              ep->SetAssignedAliases(rcf.m_terminalAlias))
+			     rcf.IncludeOptionalField(H225_RegistrationConfirm::e_terminalAlias);
+
+#ifdef h323v6
+        // Assigned GKs
+	    if (request.HasOptionalField(H225_RegistrationRequest::e_assignedGatekeeper)) 
+            ep->SetAssignedGatekeeper(rcf.m_assignedGatekeeper);
+#endif
+
 		// Alternate GKs
 		if (request.HasOptionalField(H225_RegistrationRequest::e_supportsAltGK))
 			RasSrv->SetAlternateGK(rcf);
-		if (ep->HasCallCreditCapabilities()) {
-			rcf.IncludeOptionalField(H225_RegistrationConfirm::e_serviceControl);
-			ep->AddCallCreditServiceControl(rcf.m_serviceControl, 
-				authData.m_amountString, authData.m_billingMode, -1
-				);
-		}
+		
+		// Call credit display 
+		if (ep->AddCallCreditServiceControl(rcf.m_serviceControl,
+			authData.m_amountString, authData.m_billingMode, -1)) 
+			  rcf.IncludeOptionalField(H225_RegistrationConfirm::e_serviceControl);
+
+		// URL link
+		if (ep->AddHTTPServiceControl(rcf.m_serviceControl) && 
+		   !rcf.HasOptionalField(H225_RegistrationConfirm::e_serviceControl))
+			      rcf.IncludeOptionalField(H225_RegistrationConfirm::e_serviceControl);
+
+#ifdef H323_H350
+		// H.350 link
+		if (ep->AddH350ServiceControl(rcf.m_serviceControl) &&
+		   !rcf.HasOptionalField(H225_RegistrationConfirm::e_serviceControl))
+			      rcf.IncludeOptionalField(H225_RegistrationConfirm::e_serviceControl);
+#endif
+
 	} else {
 		PIPSocket::Address rasip, sigip;
 		if (GetIPFromTransportAddr(request.m_rasAddress[0], rasip) && GetIPFromTransportAddr(SignalAddr, sigip) && rasip != sigip)
@@ -2077,6 +2194,24 @@ bool AdmissionRequestPDU::Process()
 		}
 	}
 
+#ifdef hasH460
+    bool QoSReporting = false;
+	bool vendorInfo = false;
+	PString m_vendor,m_version = PString();
+	if (request.HasOptionalField(H225_AdmissionRequest::e_genericData)) {  
+		H225_ArrayOf_GenericData & data = request.m_genericData;
+		for (PINDEX i =0; i < data.GetSize(); i++) {
+          H460_Feature & feat = (H460_Feature &)data[i];
+		  /// Vendor Information
+  		  if (feat.GetFeatureID() == H460_FeatureID(OpalOID(OID9))) 
+		     vendorInfo = true;
+          /// H.460.9 QoS Reporting
+		  if (feat.GetFeatureID() == H460_FeatureID(9)) 
+             QoSReporting = true;
+		}
+	}
+#endif
+
 	//
 	// Bandwidth
 	// and GkManager admission
@@ -2124,7 +2259,7 @@ bool AdmissionRequestPDU::Process()
 			
 		list<Route>::iterator r = arq.GetRoutes().begin();
 		while (r != arq.GetRoutes().end()) {
-			// PTRACE(1, "JW route = " << r->AsString() );
+			// PTRACE(1, "route = " << r->AsString() );
 			if (authData.m_proxyMode != CallRec::ProxyDetect)
 				r->m_proxyMode = authData.m_proxyMode;
 			++r;
@@ -2133,7 +2268,8 @@ bool AdmissionRequestPDU::Process()
 		Route route;
 		arq.GetFirstRoute(route);
 		
-		if (route.m_destEndpoint && !route.m_destEndpoint->HasAvailableCapacity())
+		if ((arq.GetRoutes().size() == 1 || !Toolkit::AsBool(GkConfig()->GetString(RoutedSec, "ActivateFailover", "0")))
+				&& route.m_destEndpoint	&& !route.m_destEndpoint->HasAvailableCapacity(request.m_destinationInfo))
 			return BuildReply(H225_AdmissionRejectReason::e_resourceUnavailable);
 
 		CalledEP = route.m_destEndpoint;
@@ -2148,53 +2284,6 @@ bool AdmissionRequestPDU::Process()
 		authData.m_proxyMode = route.m_proxyMode;
 	}
 
-#ifdef ARJREASON_ROUTECALLTOSCN
- 	//
- 	// call from one GW to itself?
- 	// generate ARJ-reason: 'routeCallToSCN'
- 	//
- 	if (Toolkit::AsBool(Kit->Config()->GetString("RasSrv::ARQFeatures", "ArjReasonRouteCallToSCN", "1"))) {
- 		// are the endpoints the same (GWs of course)?
-		// only first ARQ may be rejected with with 'routeCallToSCN
- 		if (CalledEP == RequestingEP && !answer) {
- 			// we have to extract the SCN from the destination. only EP-1 will be rejected this way
-			if (bHasDestInfo) {
-				// set the ARJ reason
-				BuildReply(H225_AdmissionRejectReason::e_routeCallToSCN);
-				H225_AdmissionReject & arj = m_msg->m_replyRAS;
-				H225_ArrayOf_PartyNumber & APN = arj.m_rejectReason;
-				APN.SetSize(1);
-				// PN will be the number that is set in the arj reason
-				H225_PartyNumber & PN = APN[0];
-				PN.SetTag(H225_PartyNumber::e_publicNumber);
-				H225_PublicPartyNumber & PPN = PN;
-				// set defaults
-				PPN.m_publicTypeOfNumber.SetTag(H225_PublicTypeOfNumber::e_unknown);
-				PPN.m_publicNumberDigits = "";
-
-				// there can be diffent information in the destination info
-				switch(request.m_destinationInfo[0].GetTag())
-				{
-					case H225_AliasAddress::e_dialedDigits:
-						// normal number, extract only the digits
-						PPN.m_publicNumberDigits = AsString(request.m_destinationInfo[0], FALSE);
-						break;
-					case H225_AliasAddress::e_partyNumber:
-						// ready-to-use party number
-						PN = request.m_destinationInfo[0];
-						break;
-					default:
-						PTRACE(1, "Unsupported AliasAdress for ARQ reason 'routeCallToSCN': " << request.m_destinationInfo[0]);
-				}
-				return true;
-			} else {
- 				// missing destination info. is this possible at this point?
- 			}
- 		}
- 	}
- 	//:towi
-#endif
-
 	// new connection admitted
 	H225_AdmissionConfirm & acf = BuildConfirm();
 	acf.m_bandWidth = BWRequest;
@@ -2293,13 +2382,44 @@ bool AdmissionRequestPDU::Process()
 		acf.m_destinationInfo = request.m_destinationInfo;
 	}
 
-	if (RequestingEP->HasCallCreditCapabilities()) {
-		acf.IncludeOptionalField(H225_AdmissionConfirm::e_serviceControl);
-		RequestingEP->AddCallCreditServiceControl(acf.m_serviceControl, 
+	if (RequestingEP->AddCallCreditServiceControl(acf.m_serviceControl, 
 			authData.m_amountString, authData.m_billingMode, 
-			authData.m_callDurationLimit
-			);
+			authData.m_callDurationLimit)) {
+			   	acf.IncludeOptionalField(H225_AdmissionConfirm::e_serviceControl);
+	        }
+
+#ifdef hasH460
+	// If we have a call record and the remote party needs NAT support 
+	// and the requesting EP can provide it then notify the EP to lend assistance.
+	if (!answer) {	
+	   PINDEX lastPos = 0;
+       H225_ArrayOf_GenericData & data = acf.m_genericData;
+   /// OID9 Vendor Information
+	   if (vendorInfo && !m_vendor.IsEmpty()) {
+	      H460_FeatureOID fs = H460_FeatureOID(OID9);
+          fs.Add(PString(VendorProdOID),H460_FeatureContent(m_vendor));
+          fs.Add(PString(VendorVerOID),H460_FeatureContent(m_version));
+          lastPos++;
+	      data.SetSize(lastPos);
+	      data[lastPos-1] = fs; 
+	   }
+   /// H.460.9 QoS Reporting
+	   if (QoSReporting && 
+		 Toolkit::AsBool(GkConfig()->GetString("GkQoSMonitor", "Enable", "0"))) {
+	     H460_FeatureStd fs = H460_FeatureStd(9);
+
+		 if (Toolkit::AsBool(GkConfig()->GetString("GkQoSMonitor", "DRQOnly", "1")))
+	                 fs.Add(0,H460_FeatureContent(0,8));
+         lastPos++;
+	     data.SetSize(lastPos);
+	     data[lastPos-1] = fs;   
+	   }
+
+	   if (lastPos > 0) 
+		  acf.IncludeOptionalField(H225_AdmissionConfirm::e_genericData);  
 	}
+#endif
+
 	return BuildReply(e_acf);
 }
 
@@ -2318,11 +2438,9 @@ bool AdmissionRequestPDU::BuildReply(int reason)
 				(const unsigned char *) destinationString,
 				(const unsigned char *) srcInfo
 		      	);
-		if (Toolkit::AsBool(GkConfig()->GetString("Gatekeeper::Main", "SignalCallId", 0))) {
-			PString callid = AsString(request.m_callIdentifier.m_guid);
-			callid.Replace(" ", "-", true);
-			log += PString("|") + callid;
-		}
+		PString callid = AsString(request.m_callIdentifier.m_guid);
+		callid.Replace(" ", "-", true);
+		log += PString("|") + callid;
 		log += PString(";");
 	} else if (reason < 0) {
 		log = PString(PString::Printf, "ACF|%s|%s|%u|%s|%s|%s",
@@ -2333,11 +2451,9 @@ bool AdmissionRequestPDU::BuildReply(int reason)
 				(const unsigned char *) srcInfo,
 				answerCall
 		      	);
-		if (Toolkit::AsBool(GkConfig()->GetString("Gatekeeper::Main", "SignalCallId", 0))) {
-			PString callid = AsString(request.m_callIdentifier.m_guid);
-			callid.Replace(" ", "-", true);
-			log += PString("|") + callid;
-		}
+		PString callid = AsString(request.m_callIdentifier.m_guid);
+		callid.Replace(" ", "-", true);
+		log += PString("|") + callid;
 		log += PString(";");
 	} else {
 		H225_AdmissionReject & arj = BuildReject(reason);
@@ -2350,11 +2466,9 @@ bool AdmissionRequestPDU::BuildReply(int reason)
 				answerCall,
 				(const unsigned char *) arj.m_rejectReason.GetTagName()
 		      	);
-		if (Toolkit::AsBool(GkConfig()->GetString("Gatekeeper::Main", "SignalCallId", 0))) {
-			PString callid = AsString(request.m_callIdentifier.m_guid);
-			callid.Replace(" ", "-", true);
-			log += PString("|") + callid;
-		}
+		PString callid = AsString(request.m_callIdentifier.m_guid);
+		callid.Replace(" ", "-", true);
+		log += PString("|") + callid;
 		log += PString(";");
 	}
 	return PrintStatus(log);
@@ -2424,6 +2538,23 @@ template<> bool RasPDU<H225_DisengageRequest>::Process()
 		rsn = H225_DisengageRejectReason::e_notRegistered;
 	}
 
+#if hasH460
+	if (request.HasOptionalField(H225_DisengageRequest::e_genericData)) {  
+		H225_ArrayOf_GenericData & data = request.m_genericData;
+		for (PINDEX i =0; i < data.GetSize(); i++) {
+          H460_Feature & feat = (H460_Feature &)data[i];
+    /// H.460.9 QoS Feature
+           if (feat.GetFeatureID() == H460_FeatureID(9)) {
+			   H460_FeatureStd & qosfeat = (H460_FeatureStd &)feat;
+			   if (qosfeat.Contains(1)) {  
+			      PASN_OctetString & rawstats = qosfeat.Value(1);
+                  CallTbl->QoSReport(*this, ep, rawstats);
+			   }
+		   }
+		}
+	}
+#endif
+
 	PString log;
 	if (bReject) {
 		H225_DisengageReject & drj = BuildReject(rsn);
@@ -2433,11 +2564,9 @@ template<> bool RasPDU<H225_DisengageRequest>::Process()
 				(unsigned) request.m_callReferenceValue,
 				(const unsigned char *) drj.m_rejectReason.GetTagName()
 		      	);
-		if (Toolkit::AsBool(GkConfig()->GetString("Gatekeeper::Main", "SignalCallId", 0))) {
-			PString callid = AsString(request.m_callIdentifier.m_guid);
-			callid.Replace(" ", "-", true);
-			log += PString("|") + callid;
-		}
+		PString callid = AsString(request.m_callIdentifier.m_guid);
+		callid.Replace(" ", "-", true);
+		log += PString("|") + callid;
 		log += PString(";");
 	} else {
 		BuildConfirm();
@@ -2448,11 +2577,9 @@ template<> bool RasPDU<H225_DisengageRequest>::Process()
 				(unsigned) request.m_callReferenceValue,
 				(const unsigned char *) request.m_disengageReason.GetTagName()
 		      	);
-		if (Toolkit::AsBool(GkConfig()->GetString("Gatekeeper::Main", "SignalCallId", 0))) {
-			PString callid = AsString(request.m_callIdentifier.m_guid);
-			callid.Replace(" ", "-", true);
-			log += PString("|") + callid;
-		}
+		PString callid = AsString(request.m_callIdentifier.m_guid);
+		callid.Replace(" ", "-", true);
+		log += PString("|") + callid;
 		log += PString(";");
 
 		if (!RasSrv->IsGKRouted() || RasSrv->RemoveCallOnDRQ())
@@ -2480,7 +2607,6 @@ template<> bool RasPDU<H225_LocationRequest>::Process()
 		Kit->RewriteE164(request.m_destinationInfo[0]);
 	}
 
-
 	unsigned reason = H225_LocationRejectReason::e_securityDenial;
 	PIPSocket::Address ipaddr;
 	WORD port;
@@ -2497,7 +2623,6 @@ template<> bool RasPDU<H225_LocationRequest>::Process()
 	if (bReject && (Toolkit::AsBool(GkConfig()->GetString(LRQFeaturesSection, "AcceptNonNeighborLRQ", "0"))))
 		                   bReject = !RasSrv->ValidatePDU(*this, reason);
 
-
 	PString sourceInfoString(fromRegEndpoint ? request.m_endpointIdentifier.GetValue() : request.HasOptionalField(H225_LocationRequest::e_gatekeeperIdentifier) ? request.m_gatekeeperIdentifier.GetValue() : m_msg->m_peerAddr.AsString());
 
 	if (!bReject) {
@@ -2507,7 +2632,8 @@ template<> bool RasPDU<H225_LocationRequest>::Process()
 		lrq.Process();
 		if (lrq.GetFirstRoute(route)) {
 			WantedEndPoint = route.m_destEndpoint;
-			if (WantedEndPoint && !WantedEndPoint->HasAvailableCapacity()) {
+			if ((lrq.GetRoutes().size() == 1 || !Toolkit::AsBool(GkConfig()->GetString(RoutedSec, "ActivateFailover", "0")))
+					&& WantedEndPoint && !WantedEndPoint->HasAvailableCapacity(request.m_destinationInfo)) {
 				bReject = true;
 				reason = H225_LocationRejectReason::e_resourceUnavailable;
 			} else {
@@ -2535,10 +2661,38 @@ template<> bool RasPDU<H225_LocationRequest>::Process()
 					&& request.m_canMapAlias) {
 					if (!lcf.HasOptionalField(H225_LocationConfirm::e_destinationInfo)) {
 						lcf.IncludeOptionalField(H225_LocationConfirm::e_destinationInfo);
+						lcf.m_destinationInfo.SetSize(1);
 					}
 					lcf.m_destinationInfo = request.m_destinationInfo;
 				}
 
+#ifdef hasH460
+               H225_ArrayOf_GenericData & data = lcf.m_genericData;
+               PINDEX lastPos = 0;
+				if ((WantedEndPoint) && (request.HasOptionalField(H225_LocationRequest::e_genericData))) {
+                  H225_ArrayOf_GenericData & locdata = request.m_genericData; 
+				  for (PINDEX i = 0; i < locdata.GetSize(); i++) {
+				   
+				  H460_Feature & feat = (H460_Feature &)locdata[i];
+				   /// OID9 Vendor Interoperability
+			       if (feat.GetFeatureID() == H460_FeatureID(OpalOID(OID9))) {
+	                  PString m_vendor,m_version = PString();
+	                  if (WantedEndPoint->GetEndpointInfo(m_vendor,m_version)) {
+						 H460_FeatureOID foid9 = H460_FeatureOID(OID9);
+						 foid9.Add(PString(VendorProdOID),H460_FeatureContent(m_vendor));
+						 foid9.Add(PString(VendorVerOID),H460_FeatureContent(m_version));
+						 lastPos++;
+						 data.SetSize(lastPos);
+						 data[lastPos-1] = foid9;
+				      }
+				   }
+				 }
+				}
+	            if (lastPos > 0) 
+		            lcf.IncludeOptionalField(H225_LocationConfirm::e_genericData); 
+#endif		            
+
+
 				log = PString(PString::Printf, "LCF|%s|%s|%s|%s;",
 					inet_ntoa(m_msg->m_peerAddr),
 					(const unsigned char *) (WantedEndPoint ? WantedEndPoint->GetEndpointIdentifier().GetValue() : AsDotString(route.m_destAddr)),
@@ -2550,9 +2704,22 @@ template<> bool RasPDU<H225_LocationRequest>::Process()
 			if (m_msg->m_replyRAS.GetTag() == H225_RasMessage::e_requestInProgress) {
 				// LRQ is forwarded
 				H225_RequestInProgress & rip = m_msg->m_replyRAS;
+				PString ripData;
+				if (rip.HasOptionalField(H225_RequestInProgress::e_nonStandardData)) {
+					int iec = Toolkit::iecUnknown;
+					if (rip.m_nonStandardData.m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_h221NonStandard) {
+						iec = Toolkit::Instance()->GetInternalExtensionCode(rip.m_nonStandardData.m_nonStandardIdentifier);
+					} else if (rip.m_nonStandardData.m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_object) {
+						PASN_ObjectId &oid = rip.m_nonStandardData.m_nonStandardIdentifier;
+						if (oid.GetDataLength() == 0)
+							iec = Toolkit::iecNeighborId;
+					}
+					if (iec == Toolkit::iecNeighborId)
+						ripData = rip.m_nonStandardData.m_data.AsString();
+				}
 				log = PString(PString::Printf, "RIP|%s|%s|%s|%s;",
 					inet_ntoa(m_msg->m_peerAddr),
-					(const unsigned char *) rip.m_nonStandardData.m_data.AsString(),
+					(const unsigned char *) ripData,
 					(const unsigned char *) AsString(request.m_destinationInfo),
 					(const unsigned char *) sourceInfoString
 				      );
@@ -2588,12 +2755,28 @@ template<> bool RasPDU<H225_InfoRequestResponse>::Process()
 	if (endptr ep = EndpointTbl->FindByEndpointId(request.m_endpointIdentifier)) {
 		ep->Update(m_msg->m_recvRAS);
 		callptr call;
-		if (request.HasOptionalField(H225_InfoRequestResponse::e_perCallInfo))
+		if (request.HasOptionalField(H225_InfoRequestResponse::e_perCallInfo) && request.m_perCallInfo.GetSize() > 0)
 			call = CallTbl->FindCallRec(request.m_perCallInfo[0].m_callIdentifier);
-		else
+		else if (request.m_callSignalAddress.GetSize() > 0)
 			call = CallTbl->FindBySignalAdr(request.m_callSignalAddress[0]);
 		if (call)
 			call->Update(request);
+#if hasH460
+		if (call && request.HasOptionalField(H225_InfoRequestResponse::e_genericData)) {  
+			H225_ArrayOf_GenericData & data = request.m_genericData;
+			for (PINDEX i =0; i < data.GetSize(); i++) {
+			  H460_Feature & feat = (H460_Feature &)data[i];
+		/// H.460.9 QoS Feature
+				if (feat.GetFeatureID() == H460_FeatureID(9)) {
+					H460_FeatureStd & qosfeat = (H460_FeatureStd &)feat;
+					if (qosfeat.Contains(1)) {  
+			           PASN_OctetString & rawstats = qosfeat.Value(1);
+                       CallTbl->QoSReport(*this, call, ep , rawstats);
+					}
+				}
+			}
+		}
+#endif
 		if (request.HasOptionalField(H225_InfoRequestResponse::e_needResponse) && request.m_needResponse) {
 			BuildConfirm();
 			PrintStatus(PString(PString::Printf, "IACK|%s;", inet_ntoa(m_msg->m_peerAddr)));
@@ -2618,20 +2801,20 @@ template<> bool RasPDU<H225_ResourcesAvailableIndicate>::Process()
 template<> bool RasPDU<H225_RegistrationReject>::Process()
 {
 	// OnRRJ
-	if ( request.HasOptionalField( H225_RegistrationReject::e_nonStandardData ) ) {
-		if ( request.m_nonStandardData.m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_h221NonStandard ) {
-//			const H225_H221NonStandard & nonStandard = request.m_nonStandardData.m_nonStandardIdentifier;
-			// RRJ from alternateGKs
-			H225_EndpointIdentifier id;
-			id = request.m_nonStandardData.m_data.AsString();
+	if (request.HasOptionalField(H225_RegistrationReject::e_nonStandardData)
+		&& request.m_nonStandardData.m_nonStandardIdentifier.GetTag() == H225_NonStandardIdentifier::e_h221NonStandard
+		&& Toolkit::Instance()->GetInternalExtensionCode((const H225_H221NonStandard&)request.m_nonStandardData.m_nonStandardIdentifier) == Toolkit::iecFailoverRAS) {
 
-			if ( endptr ep = EndpointTbl->FindByEndpointId( id ) )  {
-				m_msg->m_replyRAS = ep->GetCompleteRegistrationRequest();
-				if (m_msg->m_replyRAS.GetTag() == H225_RasMessage::e_registrationRequest) {
-          				CopyNonStandardData(request, (H225_RegistrationRequest &)m_msg->m_replyRAS);
-					PTRACE(3, "RAS\tSending full RRQ to " << m_msg->m_peerAddr );
-					return true;
-				}
+		// RRJ from alternateGKs
+		H225_EndpointIdentifier id;
+		id = request.m_nonStandardData.m_data.AsString();
+
+		if (endptr ep = EndpointTbl->FindByEndpointId(id))  {
+			m_msg->m_replyRAS = ep->GetCompleteRegistrationRequest();
+			if (m_msg->m_replyRAS.GetTag() == H225_RasMessage::e_registrationRequest) {
+				CopyNonStandardData(request, (H225_RegistrationRequest &)m_msg->m_replyRAS);
+				PTRACE(3, "RAS\tSending full RRQ to " << m_msg->m_peerAddr);
+				return true;
 			}
 		}
 	}
