@@ -17,11 +17,10 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef RASSRV_H
-#define RASSRV_H "@(#) $Id: RasSrv.h,v 1.40 2006/09/16 20:42:50 shorne Exp $"
+#define RASSRV_H "@(#) $Id: RasSrv.h,v 1.45 2007/11/19 20:15:34 willamowius Exp $"
 
 #include <vector>
 #include <list>
-#include "h323util.h"
 #include "yasocket.h"
 #include "singleton.h"
 #include "RasTbl.h"
@@ -79,6 +78,12 @@ public:
 	// set routed method
 	void SetRoutedMode(bool, bool);
 
+	// Set the ENUM Servers
+	void SetENUMServers();
+
+	// Set the RDS Servers
+	void SetRDSServers();
+
 	bool IsGKRouted() const { return GKRoutedSignaling; }
 	bool IsH245Routed() const { return GKRoutedH245; }
 	bool AcceptUnregisteredCalls(const PIPSocket::Address &) const;
@@ -183,6 +188,39 @@ public:
 		}
 	}
 
+#ifdef h323v6
+	template<class RAS> bool HasAssignedGK(const PString & alias,const PIPSocket::Address & ip, RAS & ras)
+	{
+
+        H225_ArrayOf_AlternateGK * assignedGK = new H225_ArrayOf_AlternateGK;
+		assignedGK->SetSize(0);
+
+		// Put query in here....
+		// Queries a DB for gatekeeper registrations with the first being
+		// the assigned gatekeeper. The alternates are then in preference order
+		// Note: If an assigned gatekeeper is found then the registration is not
+		// handled by this gatekeeper but by the assigned gatekeeper.
+		if (!Toolkit::Instance()->AssignedGKs().GetAssignedGK(alias,ip,*assignedGK))
+			return false;
+
+		if (assignedGK->GetSize() == 0)
+			return false;
+
+        ras.IncludeOptionalField(RAS::e_assignedGatekeeper);
+		ras.m_assignedGatekeeper = (*assignedGK)[0];
+
+		if (assignedGK->GetSize() > 1) {
+			for (PINDEX i=1; i< assignedGK->GetSize(); i++) {
+			   ras.m_alternateGatekeeper.SetSize(i);
+			   ras.m_alternateGatekeeper[i-1] = (*assignedGK)[i];
+			}
+		  ras.IncludeOptionalField(RAS::e_alternateGatekeeper);
+		}
+
+		return true;
+	}
+#endif
+
 	// override from class RegularJob
 	virtual void Run();
 
