@@ -10,7 +10,7 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef RASTBL_H
-#define RASTBL_H "@(#) $Id: RasTbl.h,v 1.139 2008/03/06 23:47:58 willamowius Exp $"
+#define RASTBL_H "@(#) $Id: RasTbl.h,v 1.139.2.1 2008/04/19 00:06:59 willamowius Exp $"
 
 #include <list>
 #include <map>
@@ -247,7 +247,7 @@ private:
 	/// Load general endpoint settings from the config
 	void LoadEndpointConfig();
 	void AddPrefixCapacities(const PString & prefixes);
-	void ParseTranslationMap(map<unsigned, unsigned> & cause_map, const PString & ini);
+	void ParseTranslationMap(std::map<unsigned, unsigned> & cause_map, const PString & ini);
 
 
 	EndpointRec();
@@ -271,7 +271,7 @@ protected:
 
 	int m_activeCall, m_connectedCall, m_totalCall;
 	/// active calls per prefix (regex)
-	map<string, int> m_activePrefixCalls;
+	std::map<string, int> m_activePrefixCalls;
 
 	int m_pollCount, m_usedCount;
 	mutable PMutex m_usedLock;
@@ -301,8 +301,8 @@ protected:
     /// Assigned Gatekeeper
 	H225_AlternateGK m_assignedGatekeeper;
 	/// cause code translation
-	map<unsigned, unsigned> m_receivedCauseMap;
-	map<unsigned, unsigned> m_sentCauseMap;
+	std::map<unsigned, unsigned> m_receivedCauseMap;
+	std::map<unsigned, unsigned> m_sentCauseMap;
 };
 
 typedef EndpointRec::Ptr endptr;
@@ -1504,7 +1504,7 @@ private:
 
 	mutable PReadWriteMutex tableLock;
 	// cid -> call
-	map<H225_CallIdentifier, PreliminaryCall*> calls;
+	std::map<H225_CallIdentifier, PreliminaryCall*> calls;
 };
 
 #endif // RASTBL_H
