@@ -595,10 +595,11 @@ VirtualQueue::~VirtualQueue()
 	m_listMutex.Wait();
 	
 	int numrequests = m_pendingRequests.size();
-	if( numrequests )
+	if( numrequests ) {
 		PTRACE(1,"VQueue\tDestroying virtual queue with "
 			<< numrequests << " pending requests"
 			);
+	}
 	RouteRequests::iterator i = m_pendingRequests.begin();
 	while (i != m_pendingRequests.end()) {
 		RouteRequest *r = *i++;
@@ -608,8 +609,9 @@ VirtualQueue::~VirtualQueue()
 	m_listMutex.Signal();
 
 	// wait a moment to give a chance to pending requests to cleanup
-	if( numrequests )
+	if( numrequests ) {
 		PThread::Sleep(500);
+	}
 }
 
 void VirtualQueue::OnReload()
@@ -1086,7 +1088,6 @@ bool VirtualQueuePolicy::OnRequest(SetupRequest & request)
 				port = GK_DEF_ENDPOINT_SIGNAL_PORT;
 			setup.m_destCallSignalAddress = SocketToH225TransportAddr(ip, port);
 		}
-		delete aliases;
 		delete callSigAdr;
 		// the trick: if empty, the request is rejected
 		// so we return true to terminate the routing
@@ -1094,9 +1095,11 @@ bool VirtualQueuePolicy::OnRequest(SetupRequest & request)
 		// rewritten, we return false to let subsequent
 		// policies determine the request
 		if (m_next == NULL || reject) {
+			delete aliases;
 			return true;
 		}
 	}
+	delete aliases;
 	return false;
 }
 
