@@ -31,6 +31,7 @@
 #include "RasSrv.h"
 #include "RasTbl.h"
 #include "SoftPBX.h"
+#include "MakeCall.h"
 #include "gktimer.h"
 #include "gk.h"
 #include "pwlib_compat.h"
@@ -78,6 +79,8 @@ void ShutdownHandler()
 	delete CallTable::Instance();
 	delete RegistrationTable::Instance();
 	delete RasServer::Instance();
+	if (MakeCallEndPoint::InstanceExists())
+		delete MakeCallEndPoint::Instance();
 	delete Toolkit::Instance();
 	PTRACE(3, "GK\tdelete ok");
 
@@ -141,7 +144,7 @@ void ReloadHandler()
 	/*
 	** Force reloading config
 	*/
-	InstanceOf<Toolkit>()->ReloadConfig();
+	Toolkit::Instance()->ReloadConfig();
 
 	SoftPBX::TimeToLive = GkConfig()->GetInteger("TimeToLive", SoftPBX::TimeToLive);
 
@@ -151,10 +154,17 @@ void ReloadHandler()
 
 	CallTable::Instance()->LoadConfig();
 	RegistrationTable::Instance()->LoadConfig();
+	CallTable::Instance()->UpdatePrefixCapacityCounters();
 
 	// don't put this in LoadConfig()
 	RasServer::Instance()->SetRoutedMode();
 
+	// Load ENUM servers
+	RasServer::Instance()->SetENUMServers();
+
+	// Load RDS servers
+	RasServer::Instance()->SetRDSServers();
+
 	RasServer::Instance()->LoadConfig();
 
 	Gatekeeper::EnableLogFileRotation();
@@ -276,13 +286,13 @@ void DumbHandler(int sig)
 
 
 // default params for overwriting
-Gatekeeper::Gatekeeper(const char * manuf,
-					   const char * name,
-					   WORD majorVersion,
-					   WORD minorVersion,
-					   CodeStatus status,
-					   WORD buildNumber)
-	: PProcess(manuf, name, majorVersion, minorVersion, status, buildNumber)
+Gatekeeper::Gatekeeper(const char * _manuf,
+					   const char * _name,
+					   WORD _majorVersion,
+					   WORD _minorVersion,
+					   CodeStatus _status,
+					   WORD _buildNumber)
+	: PProcess(_manuf, _name, _majorVersion, _minorVersion, _status, _buildNumber)
 {
 }
 
@@ -314,7 +324,7 @@ const PString Gatekeeper::GetArgumentsParseString() const
 }
 
 
-BOOL Gatekeeper::InitHandlers(const PArgList& args)
+bool Gatekeeper::InitHandlers(const PArgList& args)
 {
 #ifdef _WIN32
 	SetConsoleCtrlHandler(WinCtrlHandlerProc, TRUE);
@@ -360,12 +370,9 @@ BOOL Gatekeeper::InitHandlers(const PArgList& args)
 }
 
 
-BOOL Gatekeeper::InitLogging(const PArgList &args)
+bool Gatekeeper::InitLogging(const PArgList &args)
 {
 #if PTRACING
-	// PTrace::SetOptions(PTrace::Timestamp | PTrace::Thread);
-	// PTrace::SetOptions(PTrace::Timestamp);
-	//PTrace::SetOptions(PTrace::DateAndTime | PTrace::TraceLevel | PTrace::Thread);
 	PTrace::SetOptions(PTrace::DateAndTime | PTrace::TraceLevel);
 	PTrace::SetLevel(args.GetOptionCount('t'));
 	if (args.HasOption('o')) {
@@ -381,27 +388,21 @@ BOOL Gatekeeper::InitLogging(const PArgList &args)
 }
 
 
-BOOL Gatekeeper::InitToolkit(const PArgList& /*args*/)
-{
-	InstanceOf<Toolkit>(); // force using the right Toolkit constructor
-
-	return TRUE;
-}
-
-
-BOOL Gatekeeper::InitConfig(const PArgList &args)
+bool Gatekeeper::InitConfig(const PArgList &args)
 {
 	// get the name of the config file
-	PFilePath fp("gatekeeper.ini");
+	PFilePath fp;
 	PString section("Gatekeeper::Main");
 
 	if (args.HasOption('c')) 
 		fp = PFilePath(args.GetOptionString('c'));
+	else
+		fp = "gatekeeper.ini";
 
 	if (args.HasOption('s')) 
 		section = args.GetOptionString('s');
 
-	InstanceOf<Toolkit>()->SetConfig(fp, section);
+	Toolkit::Instance()->SetConfig(fp, section);
 
 	if( (GkConfig()->GetInteger("Fortytwo")  != 42) &&
 		(GkConfig()->GetInteger("Fourtytwo") != 42)) { 
@@ -485,7 +486,7 @@ void Gatekeeper::Main()
 	}
 #endif
 
-	if(!InitLogging(args) || !InitToolkit(args))
+	if(!InitLogging(args))
 		return;
 
 	if (args.HasOption('h')) {
@@ -508,7 +509,7 @@ void Gatekeeper::Main()
 	vector<PIPSocket::Address> GKHome;
 	PString home(Toolkit::Instance()->GetGKHome(GKHome));
 	if (GKHome.empty()) {
-		cerr << "Fatal: Cannot find any interface to run GnuGK!\n";
+		cerr << "Fatal: Cannot find any interface to run GnuGk!\n";
 		ExitGK();
 	}
 	cout << "Listen on " << home << "\n";
@@ -555,6 +556,12 @@ void Gatekeeper::Main()
 		RasSrv->SetRoutedMode(false, false);
 	else
 		RasSrv->SetRoutedMode();
+   
+	// Load ENUM servers
+	RasSrv->SetENUMServers();
+
+	// Load RDS servers
+	RasSrv->SetRDSServers();	
 
 #if defined(_WIN32)
 	// 1) prevent CTRL_CLOSE_EVENT, CTRL_LOGOFF_EVENT and CTRL_SHUTDOWN_EVENT 
@@ -815,7 +822,9 @@ bool Gatekeeper::SetLogFilename(
 	
 	PTrace::SetStream(&cerr);
 	
+#ifndef hasDeletingSetStream
 	delete m_logFile;
+#endif
 	m_logFile = NULL;
 	
 	m_logFilename = filename;
@@ -837,7 +846,9 @@ bool Gatekeeper::RotateLogFile()
 	if (m_logFile) {
 		PTRACE(1, "GK\tLogging closed (log file rotation)");
 		PTrace::SetStream(&cerr); // redirect to cerr
+#ifndef hasDeletingSetStream
 		delete m_logFile;
+#endif
 		m_logFile = NULL;
 	}
 
@@ -883,7 +894,9 @@ bool Gatekeeper::ReopenLogFile()
 	if (m_logFile) {
 		PTRACE(1, "GK\tLogging closed (reopen log file)");
 		PTrace::SetStream(&cerr); // redirect to cerr
+#ifndef hasDeletingSetStream
 		delete m_logFile;
+#endif
 		m_logFile = NULL;
 	}
 
@@ -921,7 +934,9 @@ void Gatekeeper::CloseLogFile()
 	if (m_logFile)
 		PTRACE(1, "GK\tLogging closed");
 	PTrace::SetStream(&cerr);
+#ifndef hasDeletingSetStream
 	delete m_logFile;
+#endif
 	m_logFile = NULL;
 }
 #endif // PTRACING
