@@ -11,7 +11,7 @@
 
 
 #ifndef GK_H
-#define GK_H "@(#) $Id: gk.h,v 1.27 2007/03/21 22:30:16 willamowius Exp $"
+#define GK_H "@(#) $Id: gk.h,v 1.30 2007/12/19 00:30:20 willamowius Exp $"
 
 #include "version.h"
 #include <ptlib/pprocess.h>
@@ -23,12 +23,12 @@ class Gatekeeper : public PProcess
 	PCLASSINFO(Gatekeeper, PProcess)
  public:
 	Gatekeeper
-		(const char * manuf = "GNU", 
-		 const char * name = "Gatekeeper", 
-		 WORD majorVersion = GNUGK_MAJOR_VERSION,
-		 WORD minorVersion = GNUGK_MINOR_VERSION,
-		 CodeStatus status = GNUGK_BUILD_TYPE,
-		 WORD buildNumber = GNUGK_BUILD_NUMBER);
+		(const char * _manuf = "GNU", 
+		 const char * _name = "Gatekeeper", 
+		 WORD _majorVersion = GNUGK_MAJOR_VERSION,
+		 WORD _minorVersion = GNUGK_MINOR_VERSION,
+		 CodeStatus _status = GNUGK_BUILD_TYPE,
+		 WORD _buildNumber = GNUGK_BUILD_NUMBER);
 
 	virtual void Main();
 
@@ -69,24 +69,17 @@ class Gatekeeper : public PProcess
 	/**@name Initialization 
 	 * A sequence of virtual initialization methods is called from #Main#
 	 * before the fun starts. 
-	 * Each one takes the already parsed command line arguments (so you can
-	 * depend the behavior on them). Later -- after #InitConfig# -- you can 
-	 * also use #Toolkit::Config()# to decide different things.
 	 * Every method may return #FALSE# to abort #Main# and end the program.
 	 */
 	//@{
 
 	/** installs the signal handlers; First called init method. */
-	virtual BOOL InitHandlers(const PArgList &args);
+	virtual bool InitHandlers(const PArgList &args);
 
-	/** factory for the static toolkit; Called after #InitHandlers#.  */
-	virtual BOOL InitToolkit(const PArgList &args);
-
-	/** factory for the static Config in Toolkit; Called after #InitToolkit# */
-	virtual BOOL InitConfig(const PArgList &args);
+	virtual bool InitConfig(const PArgList &args);
 
 	/** initiates logging and tracing; Called after #InitConfig# */
-	virtual BOOL InitLogging(const PArgList &args);
+	virtual bool InitLogging(const PArgList &args);
 
 	/** print the available command-line-options **/
 	void PrintOpts(void);
