@@ -10,8 +10,11 @@
 //////////////////////////////////////////////////////////////////
 
 #if defined(_WIN32) && (_MSC_VER <= 1200)
-#pragma warning(disable:4786) // warning about too long debug symbol off
-#pragma warning(disable:4284)
+  #pragma warning(disable:4786) // warning about too long debug symbol off
+  #pragma warning(disable:4284)
+#endif
+#if defined(_WIN32) && (_MSC_VER > 1300)
+  #pragma warning(disable:4244) // warning about possible loss of data
 #endif
 
 #include <ptlib.h>
@@ -30,6 +33,12 @@
 #include "gkauth.h"
 #include "pwlib_compat.h"
 
+#if H323_H350
+  extern const char *H350Section;
+  #include <ptclib/pldap.h>
+  #include "h350/h350.h"
+#endif
+
 namespace {
 const char* const GkAuthSectionName = "Gatekeeper::Auth";
 const char OID_CAT[] = "1.2.840.113548.10.1.2.1";
@@ -65,19 +74,20 @@ ARQAuthData::ARQAuthData(
 
 ARQAuthData& ARQAuthData::operator=(const ARQAuthData& obj)
 {
-	m_callDurationLimit = obj.m_callDurationLimit; 
-	m_requestingEP = obj.m_requestingEP;
-	m_call = obj.m_call;
-	m_billingMode = obj.m_billingMode;
-	m_proxyMode = obj.m_proxyMode;
-	
-	delete m_routeToAlias;
-	m_routeToAlias = NULL;
-	if (obj.m_routeToAlias)
-		m_routeToAlias = new H225_AliasAddress(*obj.m_routeToAlias);
+	if (this != &obj) {
+		m_callDurationLimit = obj.m_callDurationLimit; 
+		m_requestingEP = obj.m_requestingEP;
+		m_call = obj.m_call;
+		m_billingMode = obj.m_billingMode;
+		m_proxyMode = obj.m_proxyMode;
 
-	m_destinationRoutes = obj.m_destinationRoutes;
-			
+		delete m_routeToAlias;
+		m_routeToAlias = NULL;
+		if (obj.m_routeToAlias)
+			m_routeToAlias = new H225_AliasAddress(*obj.m_routeToAlias);
+
+		m_destinationRoutes = obj.m_destinationRoutes;
+	}
 	return *this;
 }
 
@@ -129,20 +139,22 @@ SetupAuthData::SetupAuthData(
 
 SetupAuthData& SetupAuthData::operator=(const SetupAuthData& obj)
 {
-	m_rejectReason = obj.m_rejectReason;
-	m_rejectCause = obj.m_rejectCause;
-	m_callDurationLimit = obj.m_callDurationLimit;
-	m_call = obj.m_call;
-	m_fromRegistered = obj.m_fromRegistered;
-	m_proxyMode = obj.m_proxyMode;
-	
-	delete m_routeToAlias;
-	m_routeToAlias = NULL;
-	if (obj.m_routeToAlias)
-		m_routeToAlias = new H225_AliasAddress(*obj.m_routeToAlias);
+	if (this != &obj) {
+		m_rejectReason = obj.m_rejectReason;
+		m_rejectCause = obj.m_rejectCause;
+		m_callDurationLimit = obj.m_callDurationLimit;
+		m_call = obj.m_call;
+		m_fromRegistered = obj.m_fromRegistered;
+		m_proxyMode = obj.m_proxyMode;
+
+		delete m_routeToAlias;
+		m_routeToAlias = NULL;
+		if (obj.m_routeToAlias)
+			m_routeToAlias = new H225_AliasAddress(*obj.m_routeToAlias);
+
+		m_destinationRoutes = obj.m_destinationRoutes;
+	}
 
-	m_destinationRoutes = obj.m_destinationRoutes;
-		
 	return *this;
 }
 
@@ -195,6 +207,8 @@ GkAuthenticator::GkAuthenticator(
 			m_controlFlag = e_Required, m_defaultStatus = e_fail;
 		else if (controlStr *= "sufficient")
 			m_controlFlag = e_Sufficient, m_defaultStatus = e_fail;
+		else if (controlStr *= "alternative")
+			m_controlFlag = e_Alternative, m_defaultStatus = e_next;
 		else
 			PTRACE(1, "GKAUTH\tInvalid control flag '" << controlStr
 				<< "' specified in the config for " << GetName()
@@ -394,15 +408,6 @@ bool GkAuthenticator::IsH235Capable() const
 	return m_h235Authenticators && m_h235Authenticators->GetSize() > 0;
 }
 
-void GkAuthenticator::SetSupportedChecks(
-	unsigned supportedRasChecks, /// RAS checks supported by this module
-	unsigned supportedMiscChecks /// non-RAS checks supported by this module
-	)
-{
-	m_supportedRasChecks = supportedRasChecks;
-	m_supportedMiscChecks = supportedMiscChecks;
-}
-
 void GkAuthenticator::AppendH235Authenticator(
 	H235Authenticator* h235Auth /// H.235 authenticator to append
 	)
@@ -656,9 +661,29 @@ PString GkAuthenticator::GetDialedNumber(
 
 // class GkAuthenticatorList
 GkAuthenticatorList::GkAuthenticatorList() 
+#ifndef OpenH323Factory
 	: m_mechanisms(new H225_ArrayOf_AuthenticationMechanism),
 	m_algorithmOIDs(new H225_ArrayOf_PASN_ObjectId)
+#endif
 {
+#ifdef OpenH323Factory
+	PStringList authlist = Toolkit::Instance()->GetAuthenticatorList();
+
+    PFactory<H235Authenticator>::KeyList_T keyList = PFactory<H235Authenticator>::GetKeyList();
+    PFactory<H235Authenticator>::KeyList_T::const_iterator r;
+    for (r = keyList.begin(); r != keyList.end(); ++r) {
+      H235Authenticator * Auth = PFactory<H235Authenticator>::CreateInstance(*r);
+      if (authlist.GetSize() > 0) {
+		for (PINDEX i=0; i< authlist.GetSize(); i++) {
+			if (PString(Auth->GetName()) == authlist[i]) {
+			   PTRACE(4,"GKAUTH\tLoaded Authenticator " << Auth->GetName() << " from Policy");
+               m_h235authenticators.Append(Auth);
+			}
+		}
+	  } else
+	        m_h235authenticators.Append(Auth);
+	}
+#endif
 }
 
 GkAuthenticatorList::~GkAuthenticatorList()
@@ -666,8 +691,11 @@ GkAuthenticatorList::~GkAuthenticatorList()
 	WriteLock lock(m_reloadMutex);
 	DeleteObjectsInContainer(m_authenticators);
 	m_authenticators.clear();
+#ifndef OpenH323Factory
 	delete m_mechanisms;
 	delete m_algorithmOIDs;
+#else
+#endif
 }
 
 void GkAuthenticatorList::OnReload()
@@ -773,7 +801,8 @@ void GkAuthenticatorList::OnReload()
 		while (iter != authenticators.end()) {
 			auth = *iter++;
 			if (auth->IsH235Capable() 
-					&& auth->GetControlFlag() == GkAuthenticator::e_Optional) {
+					&& (auth->GetControlFlag() == GkAuthenticator::e_Optional
+						|| auth->GetControlFlag() == GkAuthenticator::e_Alternative)) {
 				if (mechanisms.GetSize() == 0) {
 					auth->GetH235Capability(mechanisms, algorithmOIDs);
 					if (algorithmOIDs.GetSize() == 0 )
@@ -840,6 +869,9 @@ void GkAuthenticatorList::OnReload()
 			PTrace::End(strm);
 #endif
 		}
+#ifdef OpenH323Factory
+	}
+#else
 	} else {
 		PTRACE(4, "GKAUTH\tH.235 security is not active or conflicting "
 			"H.235 capabilities are active - GCF will not select "
@@ -852,6 +884,7 @@ void GkAuthenticatorList::OnReload()
 	// now switch to new setting
 	*m_mechanisms = mechanisms;
 	*m_algorithmOIDs = algorithmOIDs;
+#endif
 }
 
 void GkAuthenticatorList::SelectH235Capability(
@@ -871,6 +904,31 @@ void GkAuthenticatorList::SelectH235Capability(
 			&& grq.m_algorithmOIDs.GetSize() > 0))
 		return;
 
+#ifdef OpenH323Factory
+    for (PINDEX auth = 0; auth < m_h235authenticators.GetSize(); auth++) {
+     for (PINDEX cap = 0; cap < grq.m_authenticationCapability.GetSize(); cap++) {
+      for (PINDEX alg = 0; alg < grq.m_algorithmOIDs.GetSize(); alg++) {
+        if (m_h235authenticators[auth].IsCapability(grq.m_authenticationCapability[cap],
+                                              grq.m_algorithmOIDs[alg])) {
+			std::list<GkAuthenticator*>::const_iterator iter = m_authenticators.begin();
+			while (iter != m_authenticators.end()) {
+			 GkAuthenticator* gkauth = *iter++;
+			  if (gkauth->IsH235Capable() && gkauth->IsH235Capability(grq.m_authenticationCapability[cap],grq.m_algorithmOIDs[alg])) {
+				PTRACE(4, "GKAUTH\tGRQ accepted on " << H323TransportAddress(gcf.m_rasAddress)
+						<< " using authenticator " << m_h235authenticators[auth]);
+				  gcf.IncludeOptionalField(H225_GatekeeperConfirm::e_authenticationMode);
+				  gcf.m_authenticationMode = grq.m_authenticationCapability[cap];
+				  gcf.IncludeOptionalField(H225_GatekeeperConfirm::e_algorithmOID);
+				  gcf.m_algorithmOID = grq.m_algorithmOIDs[alg];
+				  return;
+			  }
+		   }
+        }
+      }
+    }
+   }
+
+#else
 	H225_ArrayOf_AuthenticationMechanism & mechanisms = *m_mechanisms;
 	H225_ArrayOf_PASN_ObjectId & algorithmOIDs = *m_algorithmOIDs;
 
@@ -904,6 +962,7 @@ void GkAuthenticatorList::SelectH235Capability(
 								<< algorithmOIDs[l] << " removed from GCF list"
 								);
 						}
+#endif
 }
 
 bool GkAuthenticatorList::Validate(
@@ -921,7 +980,8 @@ bool GkAuthenticatorList::Validate(
 			const int result = auth->Check(request, authData);
 			if (result == GkAuthenticator::e_ok) {
 				PTRACE(3, "GKAUTH\t" << auth->GetName() << " RRQ check ok");
-				if (auth->GetControlFlag() != GkAuthenticator::e_Required)
+				if (auth->GetControlFlag() == GkAuthenticator::e_Sufficient
+						|| auth->GetControlFlag() == GkAuthenticator::e_Alternative)
 					return true;
 			} else if (result == GkAuthenticator::e_fail) {
 				PTRACE(3, "GKAUTH\t" << auth->GetName() << " RRQ check failed");
@@ -962,7 +1022,8 @@ bool GkAuthenticatorList::Validate(
 					);
 			if (result == GkAuthenticator::e_ok) {
 				PTRACE(3, "GKAUTH\t" << auth->GetName() << " ARQ check ok");
-				if (auth->GetControlFlag() != GkAuthenticator::e_Required)
+				if (auth->GetControlFlag() == GkAuthenticator::e_Sufficient
+						|| auth->GetControlFlag() == GkAuthenticator::e_Alternative)
 					return true;
 			} else if (result == GkAuthenticator::e_fail) {
 				PTRACE(3, "GKAUTH\t" << auth->GetName() << " ARQ check failed");
@@ -1004,7 +1065,8 @@ bool GkAuthenticatorList::Validate(
 					);
 			if (result == GkAuthenticator::e_ok) {
 				PTRACE(3, "GKAUTH\t" << auth->GetName() << " Setup check ok");
-				if (auth->GetControlFlag() != GkAuthenticator::e_Required)
+				if (auth->GetControlFlag() == GkAuthenticator::e_Sufficient
+						|| auth->GetControlFlag() == GkAuthenticator::e_Alternative)
 					return true;
 			} else if (result == GkAuthenticator::e_fail) {
 				PTRACE(3, "GKAUTH\t" << auth->GetName() << " Setup check failed");
@@ -1070,11 +1132,19 @@ SimplePasswordAuth::SimplePasswordAuth(
 	m_cache = new CacheManager(GetConfig()->GetInteger(name, "PasswordTimeout", -1));
 
 #ifdef OpenH323Factory
+	PStringList authlist = Toolkit::Instance()->GetAuthenticatorList();
+
     PFactory<H235Authenticator>::KeyList_T keyList = PFactory<H235Authenticator>::GetKeyList();
     PFactory<H235Authenticator>::KeyList_T::const_iterator r;
     for (r = keyList.begin(); r != keyList.end(); ++r) {
-       H235Authenticator * Auth = PFactory<H235Authenticator>::CreateInstance(*r);
-       AppendH235Authenticator(Auth);
+      H235Authenticator * Auth = PFactory<H235Authenticator>::CreateInstance(*r);
+       if (authlist.GetSize() > 0) {
+		for (PINDEX i=0; i< authlist.GetSize(); i++) {
+			if (PString(Auth->GetName()) == authlist[i])
+               AppendH235Authenticator(Auth);
+		}
+	   } else
+	       AppendH235Authenticator(Auth);
 	}
 #else
 	H235Authenticator* authenticator;
@@ -1363,9 +1433,9 @@ int SimplePasswordAuth::CheckCryptoTokens(
 				}
 				
 				// check all endpoint aliases for a password
-				const H225_ArrayOf_AliasAddress aliases = ep->GetAliases();
-				for (PINDEX i = 0; i < aliases.GetSize(); i++) {
-					id = AsString(aliases[i], FALSE);
+				const H225_ArrayOf_AliasAddress pwaliases = ep->GetAliases();
+				for (PINDEX p = 0; p < pwaliases.GetSize(); p++) {
+					id = AsString(pwaliases[p], FALSE);
 					passwordFound = InternalGetPassword(id, passwd);
 					if (passwordFound)
 						break;
@@ -1448,6 +1518,62 @@ bool SimplePasswordAuth::ResolveUserName(
 	return false;
 }
 
+#ifdef H323_H350
+
+H350PasswordAuth::H350PasswordAuth(const char* authName)
+: SimplePasswordAuth(authName)
+{
+
+}
+	
+H350PasswordAuth::~H350PasswordAuth()
+{
+
+}
+
+bool H350PasswordAuth::GetPassword(const PString& alias,PString& password)
+{
+
+// Search the Directory
+	PString search = GkConfig()->GetString(H350Section, "SearchBaseDN", "");
+
+	H225_AliasAddress aliasaddress;
+	H323SetAliasAddress(alias, aliasaddress);
+
+	PString filter = "h235IdentityEndpointID=" + alias;
+
+	H350_Session session;
+	if (!Toolkit::Instance()->CreateH350Session(&session)) {
+	   PTRACE(4,"H350\tH235Auth: Could not connect to Server.");
+	   return false;
+	}
+
+	H350_Session::LDAP_RecordList rec;
+	int count = session.Search(search,filter,rec);
+	if (count <= 0) {
+	   PTRACE(4,"H350\tH235Auth:No Record Found");
+	   session.Close();
+	   return false;
+	}
+
+// Locate the record
+	for (H350_Session::LDAP_RecordList::const_iterator x = rec.begin(); x != rec.end(); ++x) {			
+       H350_Session::LDAP_Record entry = x->second;
+	   if (session.GetAttribute(entry,"h235IdentityPassword",password)) {
+           PTRACE(2,"H350\tH235Auth:Password Located.");
+	       session.Close();
+		   return true;
+	   }
+	}
+
+	PTRACE(4,"H350\tH235Auth: No Password found.");
+	session.Close();
+	return false;
+
+}
+
+#endif
+
 // class AliasAuth
 AliasAuth::AliasAuth(
 	const char* name,
@@ -2060,7 +2186,7 @@ PrefixAuth::PrefixAuth(
 		rls = NULL;
 	}
 
-	if (m_prefrules.size() == 0)
+	if (m_prefrules.empty())
 		PTRACE(1, "GKAUTH\t" << GetName() << " contains no rules - "
 			"check the config"
 			);
@@ -2174,6 +2300,9 @@ int PrefixAuth::doCheck(
 namespace { // anonymous namespace
 	GkAuthCreator<GkAuthenticator> DefaultAuthenticatorCreator("default");
 	GkAuthCreator<SimplePasswordAuth> SimplePasswordAuthCreator("SimplePasswordAuth");
+#if H323_H350
+	GkAuthCreator<H350PasswordAuth> SQLPasswordAuthCreator("H350PasswordAuth");
+#endif
 	GkAuthCreator<AliasAuth> AliasAuthCreator("AliasAuth");
 	GkAuthCreator<PrefixAuth> PrefixAuthCreator("PrefixAuth");
 } // end of anonymous namespace
