@@ -12,13 +12,15 @@
 //////////////////////////////////////////////////////////////////
 
 #ifndef GKAUTH_H
-#define GKAUTH_H "@(#) $Id: gkauth.h,v 1.31 2007/03/21 22:30:16 willamowius Exp $"
+#define GKAUTH_H "@(#) $Id: gkauth.h,v 1.39 2008/03/07 15:46:55 zvision Exp $"
 
 #include <map>
 #include <list>
 #include "name.h"
 #include "rwlock.h"
 #include <h235auth.h>
+#include "Toolkit.h"
+#include "h323util.h"
 
 class H225_GatekeeperRequest;
 class H225_GatekeeperConfirm;
@@ -40,7 +42,6 @@ class H235_AuthenticationMechanism;
 class PASN_ObjectId;
 class H235Authenticators;
 class H235Authenticator;
-class Q931;
 class H225_Setup_UUIE;
 class SignalingMsg;
 template <class> class H225SignalingMsg;
@@ -194,7 +195,7 @@ public:
 		/// if this module cannot determine authentication success or failure
 		/// (due to some missing info, for example), remaining modules will
 		/// decide about acceptation/rejection of the reqest,
-		/// otherwise auth processing ends at this module
+		/// if the request is accepted it is passed to a next rule
 		e_Optional, 
 		/// the request has to be authenticated by this module
 		/// and processing is continued with remaining modules
@@ -202,7 +203,10 @@ public:
 		/// if the request is authenticated by this module, authentication
 		/// is successful, otherwise the request is rejected
 		/// (no further modules are processed in both cases)
-		e_Sufficient 
+		e_Sufficient,
+		/// if the request is accepted/rejected by this module, authentication
+		/// processing ends, otherwise the request is passed to a next rule
+		e_Alternative
 	};
 
 	/// authentication status returned from Check methods
@@ -346,22 +350,6 @@ protected:
 	*/
 	PConfig* GetConfig() const { return m_config; }
 
-	/// Set bitmasks for checks supported (implemented) by this authenticator
-	void SetSupportedChecks(
-		unsigned supportedRasChecks, /// RAS checks supported by this module
-		unsigned supportedMiscChecks /// non-RAS checks supported by this module
-		);
-
-	/** @return
-	    Bitmask for RAS checks supported/implemented by this authenticator.
-	*/
-	unsigned GetSupportedRasChecks() const { return m_supportedRasChecks; }
-
-	/** @return
-	    Bitmask for non-RAS checks supported/implemented by this authenticator.
-	*/
-	unsigned GetSupportedMiscChecks() const { return m_supportedMiscChecks; }
-
 	/** Should be called only from derived constructor to add supported
 	    H.235 capabilities (if any).
 	*/
@@ -648,16 +636,22 @@ protected:
 		bool finalResult = false;
 		
 #ifdef OpenH323Factory
+
+		if (m_h235Authenticators == NULL) {
+			PTRACE(4, "GKAUTH\tSuccess: No Loaded Authenticators");
+			return e_ok;
+		}
+
 		PString username = PString();
 		PString password = PString();
 		if (!ResolveUserName(req.m_tokens, req.m_cryptoTokens,username)) {
             PTRACE(4, "GKAUTH\t" << GetName() << " No username resolved from tokens.");
-			return false;
+			return e_fail;
 		}
 
 		if ((aliases == NULL) || (FindAlias(*aliases, username) == P_MAX_INDEX)) {
             PTRACE(4, "GKAUTH\t" << GetName() << " Token username " << username << " does not match aliases for Endpoint");
-			return false;
+			return e_fail;
 		}
 
 		if (!InternalGetPassword(username, password)) {
@@ -668,26 +662,27 @@ protected:
         for (PINDEX i = 0; i < m_h235Authenticators->GetSize();  i++) {
           H235Authenticator * authenticator = (H235Authenticator *)(*m_h235Authenticators)[i].Clone();
 
-		  authenticator->SetLocalId(username);
+		  authenticator->SetLocalId(Toolkit::GKName());
+		  authenticator->SetRemoteId(username);
 		  authenticator->SetPassword(password);
 
           H235Authenticator::ValidationResult result = authenticator->ValidateTokens(req.m_tokens, 
 			                                                        req.m_cryptoTokens, request->m_rasPDU);
           switch (result) {
              case H235Authenticator::e_OK :
-               PTRACE(4, "GKAUTH\tAuthenticator " << authenticator << " succeeded");
+               PTRACE(4, "GKAUTH\tAuthenticator " << authenticator->GetName() << " succeeded");
                return e_ok;
 
              case H235Authenticator::e_Absent :
-               PTRACE(6, "GKAUTH\tAuthenticator " << authenticator << " absent from PDU");
+               PTRACE(6, "GKAUTH\tAuthenticator " << authenticator->GetName() << " absent from PDU");
                break;
 
              case H235Authenticator::e_Disabled :
-               PTRACE(6, "GKAUTH\tAuthenticator " << authenticator << " disabled");
+               PTRACE(6, "GKAUTH\tAuthenticator " << authenticator->GetName() << " disabled");
                break;
 
              default : // Various other failure modes
-               PTRACE(6, "GKAUTH\tAuthenticator " << authenticator << " failed: " << (int)result);
+               PTRACE(6, "GKAUTH\tAuthenticator " << authenticator->GetName() << " failed: " << (int)result);
                return e_fail;
            }
 
@@ -744,6 +739,38 @@ private:
 };
 
 
+#ifdef H323_H350
+
+/// Generic SQL authenticator for H.235 enabled endpoints
+class H350PasswordAuth : public SimplePasswordAuth
+{
+public:
+	/// build authenticator reading settings from the config
+	H350PasswordAuth(
+		/// name for this authenticator and for the config section to read settings from
+		const char* authName
+		);
+	
+	virtual ~H350PasswordAuth();
+
+protected:
+	/** Override from SimplePasswordAuth.
+	
+	    @return
+	    True if the password has been found for the given alias.
+	*/
+	virtual bool GetPassword(
+		/// alias to check the password for
+		const PString& alias,
+		/// password string, if the match is found
+		PString& password
+		);
+
+};
+
+#endif
+
+
 /** A base class for all authenticators that validate endpoints (requests)
     by alias and/or IP address only.
 	
@@ -889,7 +916,8 @@ public:
 					PTRACE(3, "GKAUTH\t" << auth->GetName() << ' ' 
 						<< request.GetTagName() << " check ok"
 						);
-					if (auth->GetControlFlag() != GkAuthenticator::e_Required)
+					if (auth->GetControlFlag() == GkAuthenticator::e_Sufficient
+							|| auth->GetControlFlag() == GkAuthenticator::e_Alternative)
 						return true;
 				} else if (result == GkAuthenticator::e_fail) {
 					PTRACE(3, "GKAUTH\t" << auth->GetName() << ' '
@@ -951,8 +979,12 @@ private:
 	PReadWriteMutex m_reloadMutex;
 	/// the most common authentication capabilities 
 	/// shared by all authenticators on the list
+#ifdef OpenH323Factory
+    H235Authenticators m_h235authenticators;
+#else
 	H225_ArrayOf_AuthenticationMechanism* m_mechanisms;
 	H225_ArrayOf_PASN_ObjectId* m_algorithmOIDs;
+#endif
 };
 
 /** A factory template for authenticator objects. When you create
