@@ -12,6 +12,12 @@
  * with the OpenH323 library.
  *
  * $Log: gkconfig.h,v $
+ * Revision 1.6  2007/11/27 12:57:27  willamowius
+ * preparation for PBoolean change in PWLib
+ *
+ * Revision 1.5  2007/09/13 11:17:11  willamowius
+ * use same parameter name in declaration and implementation
+ *
  * Revision 1.4  2006/04/14 13:56:19  willamowius
  * call failover code merged
  *
@@ -32,7 +38,9 @@
  *
  */
 #ifndef GKCONFIG_H 
-#define GKCONFIG_H "@(#) $Id: gkconfig.h,v 1.4 2006/04/14 13:56:19 willamowius Exp $"
+#define GKCONFIG_H "@(#) $Id: gkconfig.h,v 1.6 2007/11/27 12:57:27 willamowius Exp $"
+
+#include "pwlib_compat.h"
 
 class GatekeeperConfig : public PConfig
 {
@@ -62,7 +70,7 @@ public:
 
 	/** Get a list of all the keys in the section. */
 	virtual PStringList GetKeys(
-		const PString& section /// Section to use instead of the default.
+		const PString& theSection /// Section to use instead of the default.
 		) const;
 
 	/** Get all of the keys in the section and their values.
@@ -79,7 +87,7 @@ public:
 	    appear in the GetSections() function.
 	*/
 	virtual void DeleteSection(
-		const PString& section /// Name of section to delete.
+		const PString& theSection /// Name of section to delete.
 		);
 
 	/** Delete the particular variable in the specified section.
@@ -90,8 +98,8 @@ public:
 	    string.
 	*/
 	virtual void DeleteKey(
-		const PString& section, /// Section to use instead of the default.
-		const PString& key /// Key of the variable to delete.
+		const PString& theSection, /// Section to use instead of the default.
+		const PString& theKey /// Key of the variable to delete.
     );
 
 	/** Determine if the particular variable in the section is actually present.
@@ -102,9 +110,9 @@ public:
 	    the default "DefVal" being used, or the user had explicitly saved the
 	    value "DefVal" into the PConfig.
 	*/
-	virtual BOOL HasKey(
-		const PString& section, /// Section to use instead of the default.
-		const PString& key /// Key of the variable.
+	virtual PBoolean HasKey(
+		const PString& theSection, /// Section to use instead of the default.
+		const PString& theKey /// Key of the variable.
 		) const;
 	//@}
 
@@ -120,8 +128,8 @@ public:
 	    @return string value of the variable.
 	*/
 	virtual PString GetString(
-		const PString& section,  /// Section to use instead of the default.
-		const PString& key,      /// The key name for the variable.
+		const PString& theSection,  /// Section to use instead of the default.
+		const PString& theKey,      /// The key name for the variable.
 		const PString& dflt      /// Default value for the variable.
 		) const;
 
@@ -140,10 +148,10 @@ public:
 
 	    @return boolean value of the variable.
 	*/
-	virtual BOOL GetBoolean(
+	virtual PBoolean GetBoolean(
 		const PString& section, /// Section to use instead of the default.
 		const PString& key, /// The key name for the variable.
-		BOOL dflt = FALSE /// Default value for the variable.
+		PBoolean dflt = FALSE /// Default value for the variable.
 		) const;
 
 	/** Get an integer variable determined by the key in the section. If the
