@@ -11,6 +11,9 @@
  * with the OpenH323 library.
  *
  * $Log: gktimer.cxx,v $
+ * Revision 1.5  2007/09/11 01:02:29  willamowius
+ * clean up includes
+ *
  * Revision 1.4  2006/04/14 13:56:19  willamowius
  * call failover code merged
  *
@@ -35,7 +38,6 @@
 #endif
 
 #include <ptlib.h>
-#include <list>
 #include "stl_supp.h"
 #include "gktimer.h"
 
