@@ -68,12 +68,12 @@ PString AsString(const H225_EndpointType & terminalType)
 	return terminalTypeString.Mid(1);
 }
 
-PString AsString(const H225_AliasAddress & terminalAlias, BOOL includeAliasName)
+PString AsString(const H225_AliasAddress & terminalAlias, bool includeAliasType)
 {
 	PString aliasString;
 
 	if(!terminalAlias.IsValid())
-		return includeAliasName ? "invalid:UnknownType" : "invalid";
+		return includeAliasType ? "invalid:UnknownType" : "invalid";
 
 	switch (terminalAlias.GetTag()) {
 		case H225_AliasAddress::e_dialedDigits:
@@ -90,18 +90,18 @@ PString AsString(const H225_AliasAddress & terminalAlias, BOOL includeAliasName)
 				if (prefixIndex != P_MAX_INDEX)
 					aliasString = aliasString.Mid(prefixIndex + 1);
 			}
-			if (includeAliasName) {
+			if (includeAliasType) {
 				aliasString += ":" + terminalAlias.GetTagName();
 			}
 			return aliasString;
 			break;
 	}
 
-	return includeAliasName ? "none:UnknownType" : "none";
+	return includeAliasType ? "none:UnknownType" : "none";
 }
 
 
-PString AsString(const H225_ArrayOf_AliasAddress & terminalAlias, BOOL includeAliasName)
+PString AsString(const H225_ArrayOf_AliasAddress & terminalAlias, bool includeAliasName)
 {
 	PString aliasListString = "";
 
@@ -128,6 +128,17 @@ PString AsString(const PASN_OctetString & Octets)
 	return result;
 }
 
+PString StripAliasType(const PString & alias)
+{
+	const PINDEX nameIndex = alias.FindLast(':');
+	if (nameIndex != P_MAX_INDEX) {
+		return alias.Left(nameIndex);
+	} else {
+		// nothing to strip
+		return alias;
+	}
+}
+
 // convert a socket IP address into an H225 transport address
 H225_TransportAddress SocketToH225TransportAddr(const PIPSocket::Address & Addr, WORD Port)
 {
@@ -177,11 +188,12 @@ bool GetIPAndPortFromTransportAddr(const H225_TransportAddress & addr, PIPSocket
 	return true;
 }
 
-bool IsRemoteNATSupport(const PString & addr)
+bool IsIPAddress(const PString & addr)
 {
-	PString ipAddr = addr.Trim();
-	PINDEX p = ipAddr.Find('*');
-	return (p != P_MAX_INDEX);
+	static PRegularExpression ipPattern("^[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+$", PRegularExpression::Extended);
+	static PRegularExpression ipAndPortPattern("^[0-9]+\\.[0-9]+\\.[0-9]+\\.[0-9]+:[0-9]+$", PRegularExpression::Extended);
+
+	return ((addr.FindRegEx(ipPattern) != P_MAX_INDEX) || (addr.FindRegEx(ipAndPortPattern) != P_MAX_INDEX));
 }
 
 bool IsLoopback(const PIPSocket::Address & addr)
