@@ -11,7 +11,7 @@
 
 
 #ifndef H323UTIL_H
-#define H323UTIL_H "@(#) $Id: h323util.h,v 1.20 2007/03/21 22:30:16 willamowius Exp $"
+#define H323UTIL_H "@(#) $Id: h323util.h,v 1.24 2007/11/19 20:15:34 willamowius Exp $"
 
 #include <ptlib/sockets.h>
 
@@ -33,12 +33,14 @@ PString AsString(const H225_TransportAddress_ipAddress & ip);
 
 PString AsString(const H225_EndpointType & terminalType);
 
-PString AsString(const H225_AliasAddress & terminalAlias, BOOL includeAliasName = TRUE);
+PString AsString(const H225_AliasAddress & terminalAlias, bool includeAliasName = TRUE);
 
-PString AsString(const H225_ArrayOf_AliasAddress & terminalAlias, BOOL includeAliasName = TRUE);
+PString AsString(const H225_ArrayOf_AliasAddress & terminalAlias, bool includeAliasName = TRUE);
 
 PString AsString(const PASN_OctetString & Octets);
 
+PString StripAliasType(const PString & alias);
+
 // convert a socket IP address into an H225 transport address
 H225_TransportAddress SocketToH225TransportAddr(const PIPSocket::Address & Addr, WORD Port);
 
@@ -50,7 +52,7 @@ bool GetIPFromTransportAddr(const H225_TransportAddress & addr, PIPSocket::Addre
 
 bool GetIPAndPortFromTransportAddr(const H225_TransportAddress & addr, PIPSocket::Address & ip, WORD & port);
 
-bool IsRemoteNATSupport(const PString & addr);
+bool IsIPAddress(const PString & addr);
 
 bool IsLoopback(const PIPSocket::Address &);
 
