@@ -11,7 +11,7 @@
 
 
 #ifndef PWLIB_COMPAT_H
-#define PWLIB_COMPAT_H "@(#) $Id: pwlib_compat.h,v 1.20 2008/02/19 16:50:03 willamowius Exp $"
+#define PWLIB_COMPAT_H "@(#) $Id: pwlib_compat.h,v 1.20.2.1 2008/03/31 17:11:24 willamowius Exp $"
 
 #include "ptbuildopts.h"
 #include "openh323buildopts.h"
@@ -84,7 +84,11 @@
 #endif
 
 #if !defined(PWLIB_MAJOR) && !defined(PTLIB_MAJOR)
-  #warning "Can't detect PWLib/PTLib version"
+  #if _WIN32
+    #pragma message ("warning: Can't detect PWLib/PTLib version")
+  #else
+    #warning "Can't detect PWLib/PTLib version"
+  #endif
   // be on the safe side and rsik a small memleak instead of a crash
   #define hasDeletingSetStream 1
 #endif
