@@ -11,6 +11,9 @@
  * with the OpenH323 library.
  *
  * $Log: radacct.cxx,v $
+ * Revision 1.21  2007/09/11 01:02:29  willamowius
+ * clean up includes
+ *
  * Revision 1.20  2006/12/06 16:34:04  zvision
  * Handle RADIUS Class attribute correctly
  *
@@ -108,8 +111,6 @@
 #include "gk_const.h"
 #include "h323util.h"
 #include "Toolkit.h"
-#include "RasTbl.h"
-#include "gkacct.h"
 #include "radproto.h"
 #include "radacct.h"
 
