@@ -11,6 +11,24 @@
  * with the OpenH323 library.
  *
  * $Log: radproto.cxx,v $
+ * Revision 1.36  2008/03/18 15:51:13  zvision
+ * Delete socket when id cannot be generated
+ *
+ * Revision 1.35  2008/01/09 00:44:07  willamowius
+ * remove unused code
+ *
+ * Revision 1.34  2007/11/25 23:23:40  willamowius
+ * cleanup: rename variables that shadow others with the same name
+ *
+ * Revision 1.33  2007/11/19 20:15:34  willamowius
+ * change BOOL to bool where it doesn't affect OpenH323 method signatures
+ *
+ * Revision 1.32  2007/09/13 11:16:12  willamowius
+ * use unique variable names
+ *
+ * Revision 1.31  2007/09/11 01:02:29  willamowius
+ * clean up includes
+ *
  * Revision 1.30  2006/07/06 15:25:13  willamowius
  * set all deleted pointers to NULL (most probably more than needed)
  *
@@ -153,7 +171,6 @@
 #endif
 
 #include <ptlib.h>
-#include <ptlib/sockets.h>
 #include <ptclib/cypher.h>
 #include <ptclib/random.h>
 #include "Toolkit.h"
@@ -1458,13 +1475,13 @@ bool RadiusPDU::EncryptPasswords(
 #endif
 
 RadiusSocket::RadiusSocket( 
-	WORD port 
+	WORD _port 
 	) : m_permanentSyncPoints(DEFAULT_PERMANENT_SYNCPOINTS),
 	m_isReading(false), m_nestedCount(0), 
 	m_idCacheTimeout(RadiusClient::DefaultIdCacheTimeout)
 {
-	if (!Listen(0, port)) {
-		PTRACE(1, "RADIUS\tCould not bind socket to the port " << port
+	if (!Listen(0, _port)) {
+		PTRACE(1, "RADIUS\tCould not bind socket to the port " << _port
 			<< " - error " << GetErrorCode(PSocket::LastGeneralError) << '/'
 			<< GetErrorNumber(PSocket::LastGeneralError) << ": " 
 			<< GetErrorText(PSocket::LastGeneralError)
@@ -1472,7 +1489,6 @@ RadiusSocket::RadiusSocket(
 		Close();
 	}
 	
-	int i;
 	PRandom random;
 	const unsigned _id_ = random;
 	m_oldestId = m_nextId = (BYTE)(_id_^(_id_>>8)^(_id_>>16)^(_id_>>24));
@@ -1484,23 +1500,23 @@ RadiusSocket::RadiusSocket(
 		memset(m_syncPointMap, 0, sizeof(m_syncPointMap));
 		memset(m_idTimestamps, 0, sizeof(m_idTimestamps));
 
-		for (i = 0; i < 256; i++)
+		for (int i = 0; i < 256; i++)
 			m_readSyncPointIndices[i] = P_MAX_INDEX;
 
-		for (i = 0; i < m_permanentSyncPoints; i++)
+		for (int i = 0; i < m_permanentSyncPoints; i++)
 			m_readSyncPoints[i] = new PSyncPoint();
 	}
 }
 
 RadiusSocket::RadiusSocket( 
 	const PIPSocket::Address& addr, 
-	WORD port
+	WORD _port
 	) : m_permanentSyncPoints(DEFAULT_PERMANENT_SYNCPOINTS),
 	m_isReading(false), m_nestedCount(0),
 	m_idCacheTimeout(RadiusClient::DefaultIdCacheTimeout)
 {
-	if (!Listen(addr, 0, port)) {
-		PTRACE(1, "RADIUS\tCould not bind socket to " << addr << ':' << port
+	if (!Listen(addr, 0, _port)) {
+		PTRACE(1, "RADIUS\tCould not bind socket to " << addr << ':' << _port
 			<< " - error " << GetErrorCode(PSocket::LastGeneralError) << '/'
 			<< GetErrorNumber(PSocket::LastGeneralError) << ": " 
 			<< GetErrorText(PSocket::LastGeneralError)
@@ -1636,7 +1652,7 @@ bool RadiusSocket::MakeRequest(
 	}
 
 	m_writeMutex.Wait();
-	BOOL result = WriteTo(request, length, serverAddress, serverPort);
+	bool result = WriteTo(request, length, serverAddress, serverPort);
 	if (!result)
 		PTRACE(5, "RADIUS\tError sending UDP packet ("
 			<< GetErrorCode(LastWriteError) << '/'
@@ -1974,18 +1990,18 @@ RadiusClient::RadiusClient(
 
 #if PTRACING
 	if (PTrace::CanTrace(4)) {
-		ostream& s = PTrace::Begin(4, __FILE__, __LINE__);
-		const int indent = s.precision() + 2;
-		s << "RADIUS\tCreated instance of RADIUS client (local if: "
+		ostream& os = PTrace::Begin(4, __FILE__, __LINE__);
+		const int indent = os.precision() + 2;
+		os << "RADIUS\tCreated instance of RADIUS client (local if: "
 			<< m_localAddress << ", default ports: " << m_authPort << ',' 
 			<< m_acctPort << ") for RADIUS servers group:";
 		for (unsigned i = 0; i < m_radiusServers.size(); i++)
-			s << '\n' << setw(indent + m_radiusServers[i]->m_serverAddress.GetLength()) 
+			os << '\n' << setw(indent + m_radiusServers[i]->m_serverAddress.GetLength()) 
 				<< m_radiusServers[i]->m_serverAddress << " (auth port: "
 				<< (m_radiusServers[i]->m_authPort == 0 ? m_authPort : m_radiusServers[i]->m_authPort)
 				<< ", acct port: " << (m_radiusServers[i]->m_acctPort == 0 ? m_acctPort : m_radiusServers[i]->m_acctPort)
 				<< ')';
-		PTrace::End(s);
+		PTrace::End(os);
 	}
 #endif
 }
@@ -2030,24 +2046,6 @@ void RadiusClient::GetServersFromString(
 	}
 }
 
-bool RadiusClient::SetClientPortRange( 
-	WORD base, /// base port number
-	WORD range /// number of ports in the range 
-	)
-{
-	if (range < 1)
-		return false;
-
-	PWaitAndSignal lock(m_socketMutex);
-	
-	m_portBase = base;
-	m_portMax = m_portBase + (((range-1) < (65535-m_portBase))
-		? (range-1) : (65535-m_portBase)
-		);
-
-	return true;
-}
-
 bool RadiusClient::SetIdCacheTimeout( 
 	const PTimeInterval& timeout /// new time interval
 	)
@@ -2067,38 +2065,6 @@ bool RadiusClient::SetIdCacheTimeout(
 	return true;
 }
 
-bool RadiusClient::SetRetryCount(
-	unsigned retries /// retry count (must be at least 1)
-	)
-{
-	if (retries < 1)
-		return false;
-
-	PWaitAndSignal lock(m_socketMutex);
-	m_numRetries = retries;
-	return true;
-}
-
-bool RadiusClient::SetRequestTimeout(
-	const PTimeInterval& timeout
-	)
-{
-	if (timeout < PTimeInterval(25))
-		return false;
-		
-	PWaitAndSignal lock(m_socketMutex);
-		
-	m_requestTimeout = timeout;
-	socket_const_iterator i = m_activeSockets.begin();
-	while (i != m_activeSockets.end()) {
-		(*i)->SetReadTimeout(timeout);
-		(*i)->SetWriteTimeout(timeout);
-		++i;
-	}
-			
-	return true;
-}
-
 bool RadiusClient::MakeRequest( 
 	const RadiusPDU& requestPDU, /// PDU with request packet
 	RadiusPDU*& responsePDU /// filled with PDU received from RADIUS server
@@ -2377,17 +2343,17 @@ bool RadiusClient::GetSocket(RadiusSocket*& socket, unsigned char& id)
 	PWaitAndSignal lock(m_socketMutex);
 	
 	const socket_iterator endIter = m_activeSockets.end();
-	socket_iterator s = m_activeSockets.begin();
+	socket_iterator si = m_activeSockets.begin();
 	
 	// find a first socket that is not busy (has at least one ID that can
 	// be used for a request)
-	while (s != endIter) {
-		const PINDEX newId = (*s)->GenerateNewId();
+	while (si != endIter) {
+		const PINDEX newId = (*si)->GenerateNewId();
 		if (newId != P_MAX_INDEX) {
 			id = (unsigned char)newId;
 			break;
 		} else
-			++s;
+			++si;
 	}
 
 	// refresh state of remaining sockets (reclaim unused request IDs)
@@ -2396,7 +2362,7 @@ bool RadiusClient::GetSocket(RadiusSocket*& socket, unsigned char& id)
 	socket_iterator i = m_activeSockets.begin();
 	
 	while (i != endIter) {
-		if (i == s) {
+		if (i == si) {
 			++i;
 			continue;
 		}
@@ -2412,8 +2378,8 @@ bool RadiusClient::GetSocket(RadiusSocket*& socket, unsigned char& id)
 			++i;
 	}
 
-	if (s != endIter) {
-		socket = *s;
+	if (si != endIter) {
+		socket = *si;
 		return true;	
 	}
 
@@ -2458,28 +2424,21 @@ bool RadiusClient::GetSocket(RadiusSocket*& socket, unsigned char& id)
 	newSocket->SetWriteTimeout(m_requestTimeout);
 	newSocket->SetIdCacheTimeout(m_idCacheTimeout);
 	
-	m_activeSockets.push_back(newSocket);
-	PTRACE(5, "RADIUS\tCreated new RADIUS client socket: " << (*newSocket));
 	
 	const PINDEX newId = newSocket->GenerateNewId();
-	if (newId == P_MAX_INDEX)
+	if (newId == P_MAX_INDEX) {
+		delete newSocket;
 		return false;
+	}
+	
+	m_activeSockets.push_back(newSocket);
+	PTRACE(5, "RADIUS\tCreated new RADIUS client socket: " << (*newSocket));
 		
 	socket = newSocket;
 	id = (unsigned char)newId;
 	return true;
 }
 
-void RadiusClient::SetSocketDeleteTimeout(
-	const PTimeInterval& timeout /// new timeout
-	)
-{
-	PWaitAndSignal lock(m_socketMutex);
-
-	if (timeout > PTimeInterval(20000))
-		m_socketDeleteTimeout = timeout;
-}
-
 RadiusSocket* RadiusClient::CreateSocket( 
 	const PIPSocket::Address& addr, 
 	WORD port
