@@ -10,7 +10,7 @@
  * We also explicitely grant the right to link this code
  * with the OpenH323 library.
  *
- * @(#) $Id: sigmsg.cxx,v 1.3 2006/04/14 13:56:19 willamowius Exp $
+ * @(#) $Id: sigmsg.cxx,v 1.5 2007/10/29 01:39:33 willamowius Exp $
  */
 #include <ptlib.h>
 #include <ptlib/sockets.h>
@@ -149,17 +149,3 @@ SignalingMsg* SignalingMsg::Create(
 	
 	return new SignalingMsg(q931pdu, uuie, localAddr, localPort, peerAddr, peerPort);
 }
-
-SignalingMsg& SignalingMsg::operator=(const SignalingMsg& obj)
-{
-	// TODO: check for equal objects, duplicate pointer content ?
-	m_q931 = obj.m_q931;
-	m_uuie = obj.m_uuie;
-	m_localAddr = obj.m_localAddr;
-	m_localPort = obj.m_localPort;
-	m_peerAddr = obj.m_peerAddr;
-	m_peerPort = obj.m_peerPort;
-	m_changed = false;
-	m_uuieChanged = false;
-	return *this;
-}
