@@ -24,7 +24,7 @@
 const PString Toolkit::GKVersion()
 {
 	return PString(PString::Printf,
-		       "Gatekeeper(%s) Version(%s) Ext(pthreads=%d,radius=%d,mysql=%d,pgsql=%d,large_fdset=%d)"
+		       "Gatekeeper(%s) Version(%s) Ext(pthreads=%d,radius=%d,mysql=%d,pgsql=%d,firebird=%d,large_fdset=%d,crypto/ssl=%d)"
 		       " Build(%s, %s) Sys(%s %s %s)\r\n",
 		       (const unsigned char*)(PProcess::Current().GetManufacturer()),
 		       (const unsigned char*)(PProcess::Current().GetVersion(true)),
@@ -48,10 +48,20 @@ const PString Toolkit::GKVersion()
 #else
 				(int)0,
 #endif
+#if HAS_FIREBIRD
+				(int)1,
+#else
+				(int)0,
+#endif
 #ifdef LARGE_FDSET
 				(int)LARGE_FDSET,
 #else
-				0,
+				(int)0,
+#endif
+#if P_SSL
+				(int)1,
+#else
+				(int)0,
 #endif
 		       __DATE__, __TIME__,
 		       (const unsigned char*)(PProcess::GetOSName()),
